// Code generated by smithy-go-codegen DO NOT EDIT.

//go:build response_snapshot

package amplifyuibuilder

import (
	"bufio"
	"bytes"
	"context"
	"errors"
	"fmt"
	"github.com/aws/aws-sdk-go-v2/service/amplifyuibuilder/types"
	smithyendpoints "github.com/aws/smithy-go/endpoints"
	"github.com/aws/smithy-go/middleware"
	"github.com/aws/smithy-go/ptr"
	smithytesting "github.com/aws/smithy-go/testing"
	smithyhttp "github.com/aws/smithy-go/transport/http"
	"io"
	"io/fs"
	"net/http"
	"net/url"
	"os"
	"strconv"
	"strings"
	"testing"
	"time"
)

const serdeRespSSPrefix = "response_snapshot"

func serdeRespSSPath(op string) string {
	return fmt.Sprintf("%s/%s.snap", serdeRespSSPrefix, op)
}

// serdeRespReadSnapshot parses a frozen wire response fixture: a status-code
// line, HTTP headers, a blank line, then the raw body.
func serdeRespReadSnapshot(op string) (int, http.Header, []byte, error) {
	raw, err := os.ReadFile(serdeRespSSPath(op))
	if err != nil {
		return 0, nil, nil, err
	}

	r := bufio.NewReader(bytes.NewReader(raw))
	statusLine, err := r.ReadString('\n')
	if err != nil {
		return 0, nil, nil, fmt.Errorf("read status line: %w", err)
	}
	status, err := strconv.Atoi(strings.TrimSpace(statusLine))
	if err != nil {
		return 0, nil, nil, fmt.Errorf("parse status: %w", err)
	}

	header := http.Header{}
	for {
		line, err := r.ReadString('\n')
		if err != nil && err != io.EOF {
			return 0, nil, nil, err
		}
		trimmed := strings.TrimRight(line, "\r\n")
		if trimmed == "" {
			break
		}
		k, v, ok := strings.Cut(trimmed, ": ")
		if !ok {
			return 0, nil, nil, fmt.Errorf("malformed header %q", trimmed)
		}
		header.Add(k, v)
		if err == io.EOF {
			break
		}
	}

	body, err := io.ReadAll(r)
	if err != nil {
		return 0, nil, nil, err
	}
	return status, header, body, nil
}

type serdeRespEndpointResolver struct{}

func (*serdeRespEndpointResolver) ResolveEndpoint(ctx context.Context, params EndpointParameters) (smithyendpoints.Endpoint, error) {
	return smithyendpoints.Endpoint{URI: url.URL{Scheme: "https", Host: "test.example.com"}}, nil
}

func serdeRespClient(status int, header http.Header, body []byte) *Client {
	return New(Options{
		Region: "us-east-1",
		HTTPClient: smithyhttp.ClientDoFunc(func(req *http.Request) (*http.Response, error) {
			resp := &http.Response{StatusCode: status, Header: header, Request: req}
			if len(body) > 0 {
				resp.ContentLength = int64(len(body))
				resp.Body = io.NopCloser(bytes.NewReader(body))
			} else {
				resp.Body = http.NoBody
			}
			return resp, nil
		}),
		EndpointResolverV2: &serdeRespEndpointResolver{},
		APIOptions: []func(*middleware.Stack) error{
			func(s *middleware.Stack) error {
				s.Finalize.Clear()
				s.Initialize.Remove("OperationInputValidation")
				return nil
			},
		},
	})
}
func TestCheckResponseSnapshot_CreateComponent(t *testing.T) {
	want := &CreateComponentOutput{
		Entity: &types.Component{
			AppId:           ptr.String("__AppId__"),
			EnvironmentName: ptr.String("__EnvironmentName__"),
			SourceId:        ptr.String("__SourceId__"),
			Id:              ptr.String("__Id__"),
			Name:            ptr.String("__Name__"),
			ComponentType:   ptr.String("__ComponentType__"),
			Properties: map[string]types.ComponentProperty{
				"key0": {
					Value: ptr.String("__Value__"),
					BindingProperties: &types.ComponentPropertyBindingProperties{
						Property: ptr.String("__Property__"),
						Field:    ptr.String("__Field__"),
					},
					CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
						Property: ptr.String("__Property__"),
						Field:    ptr.String("__Field__"),
					},
					DefaultValue: ptr.String("__DefaultValue__"),
					Model:        ptr.String("__Model__"),
					Bindings: map[string]types.FormBindingElement{
						"key0": {
							Element:  ptr.String("__Element__"),
							Property: ptr.String("__Property__"),
						},
					},
					Event:         ptr.String("__Event__"),
					UserAttribute: ptr.String("__UserAttribute__"),
					Concat: []types.ComponentProperty{
						{},
						{},
					},
					Condition: &types.ComponentConditionProperty{
						Property:    ptr.String("__Property__"),
						Field:       ptr.String("__Field__"),
						Operator:    ptr.String("__Operator__"),
						Operand:     ptr.String("__Operand__"),
						Then:        nil,
						Else:        nil,
						OperandType: ptr.String("__OperandType__"),
					},
					Configured:    ptr.Bool(true),
					Type:          ptr.String("__Type__"),
					ImportedValue: ptr.String("__ImportedValue__"),
					ComponentName: ptr.String("__ComponentName__"),
					Property:      ptr.String("__Property__"),
				},
			},
			Children: []types.ComponentChild{
				{
					ComponentType: ptr.String("__ComponentType__"),
					Name:          ptr.String("__Name__"),
					Properties: map[string]types.ComponentProperty{
						"key0": {
							Value: ptr.String("__Value__"),
							BindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							DefaultValue: ptr.String("__DefaultValue__"),
							Model:        ptr.String("__Model__"),
							Bindings: map[string]types.FormBindingElement{
								"key0": {
									Element:  ptr.String("__Element__"),
									Property: ptr.String("__Property__"),
								},
							},
							Event:         ptr.String("__Event__"),
							UserAttribute: ptr.String("__UserAttribute__"),
							Concat: []types.ComponentProperty{
								{},
								{},
							},
							Condition: &types.ComponentConditionProperty{
								Property:    ptr.String("__Property__"),
								Field:       ptr.String("__Field__"),
								Operator:    ptr.String("__Operator__"),
								Operand:     ptr.String("__Operand__"),
								Then:        nil,
								Else:        nil,
								OperandType: ptr.String("__OperandType__"),
							},
							Configured:    ptr.Bool(true),
							Type:          ptr.String("__Type__"),
							ImportedValue: ptr.String("__ImportedValue__"),
							ComponentName: ptr.String("__ComponentName__"),
							Property:      ptr.String("__Property__"),
						},
					},
					Children: []types.ComponentChild{
						{},
						{},
					},
					Events: map[string]types.ComponentEvent{
						"key0": {
							Action: ptr.String("__Action__"),
							Parameters: &types.ActionParameters{
								Type: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Url: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Anchor: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Target: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Global: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Model: ptr.String("__Model__"),
								Id: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Fields: map[string]types.ComponentProperty{
									"key0": {
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
								},
								State: &types.MutationActionSetStateParameter{
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
									Set: &types.ComponentProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
								},
							},
							BindingEvent: ptr.String("__BindingEvent__"),
						},
					},
					SourceId: ptr.String("__SourceId__"),
				},
				{
					ComponentType: ptr.String("__ComponentType__"),
					Name:          ptr.String("__Name__"),
					Properties: map[string]types.ComponentProperty{
						"key0": {
							Value: ptr.String("__Value__"),
							BindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							DefaultValue: ptr.String("__DefaultValue__"),
							Model:        ptr.String("__Model__"),
							Bindings: map[string]types.FormBindingElement{
								"key0": {
									Element:  ptr.String("__Element__"),
									Property: ptr.String("__Property__"),
								},
							},
							Event:         ptr.String("__Event__"),
							UserAttribute: ptr.String("__UserAttribute__"),
							Concat: []types.ComponentProperty{
								{},
								{},
							},
							Condition: &types.ComponentConditionProperty{
								Property:    ptr.String("__Property__"),
								Field:       ptr.String("__Field__"),
								Operator:    ptr.String("__Operator__"),
								Operand:     ptr.String("__Operand__"),
								Then:        nil,
								Else:        nil,
								OperandType: ptr.String("__OperandType__"),
							},
							Configured:    ptr.Bool(true),
							Type:          ptr.String("__Type__"),
							ImportedValue: ptr.String("__ImportedValue__"),
							ComponentName: ptr.String("__ComponentName__"),
							Property:      ptr.String("__Property__"),
						},
					},
					Children: []types.ComponentChild{
						{},
						{},
					},
					Events: map[string]types.ComponentEvent{
						"key0": {
							Action: ptr.String("__Action__"),
							Parameters: &types.ActionParameters{
								Type: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Url: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Anchor: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Target: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Global: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Model: ptr.String("__Model__"),
								Id: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Fields: map[string]types.ComponentProperty{
									"key0": {
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
								},
								State: &types.MutationActionSetStateParameter{
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
									Set: &types.ComponentProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
								},
							},
							BindingEvent: ptr.String("__BindingEvent__"),
						},
					},
					SourceId: ptr.String("__SourceId__"),
				},
			},
			Variants: []types.ComponentVariant{
				{
					VariantValues: map[string]string{
						"key0": "__Value__",
					},
					Overrides: map[string]map[string]string{
						"key0": {
							"key0": "__Value__",
						},
					},
				},
				{
					VariantValues: map[string]string{
						"key0": "__Value__",
					},
					Overrides: map[string]map[string]string{
						"key0": {
							"key0": "__Value__",
						},
					},
				},
			},
			Overrides: map[string]map[string]string{
				"key0": {
					"key0": "__Value__",
				},
			},
			BindingProperties: map[string]types.ComponentBindingPropertiesValue{
				"key0": {
					Type: ptr.String("__Type__"),
					BindingProperties: &types.ComponentBindingPropertiesValueProperties{
						Model: ptr.String("__Model__"),
						Field: ptr.String("__Field__"),
						Predicates: []types.Predicate{
							{
								Or: []types.Predicate{
									{},
									{},
								},
								And: []types.Predicate{
									{},
									{},
								},
								Field:       ptr.String("__Field__"),
								Operator:    ptr.String("__Operator__"),
								Operand:     ptr.String("__Operand__"),
								OperandType: ptr.String("__OperandType__"),
							},
							{
								Or: []types.Predicate{
									{},
									{},
								},
								And: []types.Predicate{
									{},
									{},
								},
								Field:       ptr.String("__Field__"),
								Operator:    ptr.String("__Operator__"),
								Operand:     ptr.String("__Operand__"),
								OperandType: ptr.String("__OperandType__"),
							},
						},
						UserAttribute: ptr.String("__UserAttribute__"),
						Bucket:        ptr.String("__Bucket__"),
						Key:           ptr.String("__Key__"),
						DefaultValue:  ptr.String("__DefaultValue__"),
						SlotName:      ptr.String("__SlotName__"),
					},
					DefaultValue: ptr.String("__DefaultValue__"),
				},
			},
			CollectionProperties: map[string]types.ComponentDataConfiguration{
				"key0": {
					Model: ptr.String("__Model__"),
					Sort: []types.SortProperty{
						{
							Field:     ptr.String("__Field__"),
							Direction: types.SortDirection("ASC"),
						},
						{
							Field:     ptr.String("__Field__"),
							Direction: types.SortDirection("ASC"),
						},
					},
					Predicate: &types.Predicate{
						Or: []types.Predicate{
							{},
							{},
						},
						And: []types.Predicate{
							{},
							{},
						},
						Field:       ptr.String("__Field__"),
						Operator:    ptr.String("__Operator__"),
						Operand:     ptr.String("__Operand__"),
						OperandType: ptr.String("__OperandType__"),
					},
					Identifiers: []string{
						"__Member__",
						"__Member__",
					},
				},
			},
			CreatedAt:  ptr.Time(time.Date(2000, 1, 1, 0, 0, 0, 0, time.UTC)),
			ModifiedAt: ptr.Time(time.Date(2000, 1, 1, 0, 0, 0, 0, time.UTC)),
			Tags: map[string]string{
				"key0": "__Value__",
			},
			Events: map[string]types.ComponentEvent{
				"key0": {
					Action: ptr.String("__Action__"),
					Parameters: &types.ActionParameters{
						Type: &types.ComponentProperty{
							Value: ptr.String("__Value__"),
							BindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							DefaultValue: ptr.String("__DefaultValue__"),
							Model:        ptr.String("__Model__"),
							Bindings: map[string]types.FormBindingElement{
								"key0": {
									Element:  ptr.String("__Element__"),
									Property: ptr.String("__Property__"),
								},
							},
							Event:         ptr.String("__Event__"),
							UserAttribute: ptr.String("__UserAttribute__"),
							Concat: []types.ComponentProperty{
								{},
								{},
							},
							Condition: &types.ComponentConditionProperty{
								Property:    ptr.String("__Property__"),
								Field:       ptr.String("__Field__"),
								Operator:    ptr.String("__Operator__"),
								Operand:     ptr.String("__Operand__"),
								Then:        nil,
								Else:        nil,
								OperandType: ptr.String("__OperandType__"),
							},
							Configured:    ptr.Bool(true),
							Type:          ptr.String("__Type__"),
							ImportedValue: ptr.String("__ImportedValue__"),
							ComponentName: ptr.String("__ComponentName__"),
							Property:      ptr.String("__Property__"),
						},
						Url: &types.ComponentProperty{
							Value: ptr.String("__Value__"),
							BindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							DefaultValue: ptr.String("__DefaultValue__"),
							Model:        ptr.String("__Model__"),
							Bindings: map[string]types.FormBindingElement{
								"key0": {
									Element:  ptr.String("__Element__"),
									Property: ptr.String("__Property__"),
								},
							},
							Event:         ptr.String("__Event__"),
							UserAttribute: ptr.String("__UserAttribute__"),
							Concat: []types.ComponentProperty{
								{},
								{},
							},
							Condition: &types.ComponentConditionProperty{
								Property:    ptr.String("__Property__"),
								Field:       ptr.String("__Field__"),
								Operator:    ptr.String("__Operator__"),
								Operand:     ptr.String("__Operand__"),
								Then:        nil,
								Else:        nil,
								OperandType: ptr.String("__OperandType__"),
							},
							Configured:    ptr.Bool(true),
							Type:          ptr.String("__Type__"),
							ImportedValue: ptr.String("__ImportedValue__"),
							ComponentName: ptr.String("__ComponentName__"),
							Property:      ptr.String("__Property__"),
						},
						Anchor: &types.ComponentProperty{
							Value: ptr.String("__Value__"),
							BindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							DefaultValue: ptr.String("__DefaultValue__"),
							Model:        ptr.String("__Model__"),
							Bindings: map[string]types.FormBindingElement{
								"key0": {
									Element:  ptr.String("__Element__"),
									Property: ptr.String("__Property__"),
								},
							},
							Event:         ptr.String("__Event__"),
							UserAttribute: ptr.String("__UserAttribute__"),
							Concat: []types.ComponentProperty{
								{},
								{},
							},
							Condition: &types.ComponentConditionProperty{
								Property:    ptr.String("__Property__"),
								Field:       ptr.String("__Field__"),
								Operator:    ptr.String("__Operator__"),
								Operand:     ptr.String("__Operand__"),
								Then:        nil,
								Else:        nil,
								OperandType: ptr.String("__OperandType__"),
							},
							Configured:    ptr.Bool(true),
							Type:          ptr.String("__Type__"),
							ImportedValue: ptr.String("__ImportedValue__"),
							ComponentName: ptr.String("__ComponentName__"),
							Property:      ptr.String("__Property__"),
						},
						Target: &types.ComponentProperty{
							Value: ptr.String("__Value__"),
							BindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							DefaultValue: ptr.String("__DefaultValue__"),
							Model:        ptr.String("__Model__"),
							Bindings: map[string]types.FormBindingElement{
								"key0": {
									Element:  ptr.String("__Element__"),
									Property: ptr.String("__Property__"),
								},
							},
							Event:         ptr.String("__Event__"),
							UserAttribute: ptr.String("__UserAttribute__"),
							Concat: []types.ComponentProperty{
								{},
								{},
							},
							Condition: &types.ComponentConditionProperty{
								Property:    ptr.String("__Property__"),
								Field:       ptr.String("__Field__"),
								Operator:    ptr.String("__Operator__"),
								Operand:     ptr.String("__Operand__"),
								Then:        nil,
								Else:        nil,
								OperandType: ptr.String("__OperandType__"),
							},
							Configured:    ptr.Bool(true),
							Type:          ptr.String("__Type__"),
							ImportedValue: ptr.String("__ImportedValue__"),
							ComponentName: ptr.String("__ComponentName__"),
							Property:      ptr.String("__Property__"),
						},
						Global: &types.ComponentProperty{
							Value: ptr.String("__Value__"),
							BindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							DefaultValue: ptr.String("__DefaultValue__"),
							Model:        ptr.String("__Model__"),
							Bindings: map[string]types.FormBindingElement{
								"key0": {
									Element:  ptr.String("__Element__"),
									Property: ptr.String("__Property__"),
								},
							},
							Event:         ptr.String("__Event__"),
							UserAttribute: ptr.String("__UserAttribute__"),
							Concat: []types.ComponentProperty{
								{},
								{},
							},
							Condition: &types.ComponentConditionProperty{
								Property:    ptr.String("__Property__"),
								Field:       ptr.String("__Field__"),
								Operator:    ptr.String("__Operator__"),
								Operand:     ptr.String("__Operand__"),
								Then:        nil,
								Else:        nil,
								OperandType: ptr.String("__OperandType__"),
							},
							Configured:    ptr.Bool(true),
							Type:          ptr.String("__Type__"),
							ImportedValue: ptr.String("__ImportedValue__"),
							ComponentName: ptr.String("__ComponentName__"),
							Property:      ptr.String("__Property__"),
						},
						Model: ptr.String("__Model__"),
						Id: &types.ComponentProperty{
							Value: ptr.String("__Value__"),
							BindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							DefaultValue: ptr.String("__DefaultValue__"),
							Model:        ptr.String("__Model__"),
							Bindings: map[string]types.FormBindingElement{
								"key0": {
									Element:  ptr.String("__Element__"),
									Property: ptr.String("__Property__"),
								},
							},
							Event:         ptr.String("__Event__"),
							UserAttribute: ptr.String("__UserAttribute__"),
							Concat: []types.ComponentProperty{
								{},
								{},
							},
							Condition: &types.ComponentConditionProperty{
								Property:    ptr.String("__Property__"),
								Field:       ptr.String("__Field__"),
								Operator:    ptr.String("__Operator__"),
								Operand:     ptr.String("__Operand__"),
								Then:        nil,
								Else:        nil,
								OperandType: ptr.String("__OperandType__"),
							},
							Configured:    ptr.Bool(true),
							Type:          ptr.String("__Type__"),
							ImportedValue: ptr.String("__ImportedValue__"),
							ComponentName: ptr.String("__ComponentName__"),
							Property:      ptr.String("__Property__"),
						},
						Fields: map[string]types.ComponentProperty{
							"key0": {
								Value: ptr.String("__Value__"),
								BindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								DefaultValue: ptr.String("__DefaultValue__"),
								Model:        ptr.String("__Model__"),
								Bindings: map[string]types.FormBindingElement{
									"key0": {
										Element:  ptr.String("__Element__"),
										Property: ptr.String("__Property__"),
									},
								},
								Event:         ptr.String("__Event__"),
								UserAttribute: ptr.String("__UserAttribute__"),
								Concat: []types.ComponentProperty{
									{},
									{},
								},
								Condition: &types.ComponentConditionProperty{
									Property:    ptr.String("__Property__"),
									Field:       ptr.String("__Field__"),
									Operator:    ptr.String("__Operator__"),
									Operand:     ptr.String("__Operand__"),
									Then:        nil,
									Else:        nil,
									OperandType: ptr.String("__OperandType__"),
								},
								Configured:    ptr.Bool(true),
								Type:          ptr.String("__Type__"),
								ImportedValue: ptr.String("__ImportedValue__"),
								ComponentName: ptr.String("__ComponentName__"),
								Property:      ptr.String("__Property__"),
							},
						},
						State: &types.MutationActionSetStateParameter{
							ComponentName: ptr.String("__ComponentName__"),
							Property:      ptr.String("__Property__"),
							Set: &types.ComponentProperty{
								Value: ptr.String("__Value__"),
								BindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								DefaultValue: ptr.String("__DefaultValue__"),
								Model:        ptr.String("__Model__"),
								Bindings: map[string]types.FormBindingElement{
									"key0": {
										Element:  ptr.String("__Element__"),
										Property: ptr.String("__Property__"),
									},
								},
								Event:         ptr.String("__Event__"),
								UserAttribute: ptr.String("__UserAttribute__"),
								Concat: []types.ComponentProperty{
									{},
									{},
								},
								Condition: &types.ComponentConditionProperty{
									Property:    ptr.String("__Property__"),
									Field:       ptr.String("__Field__"),
									Operator:    ptr.String("__Operator__"),
									Operand:     ptr.String("__Operand__"),
									Then:        nil,
									Else:        nil,
									OperandType: ptr.String("__OperandType__"),
								},
								Configured:    ptr.Bool(true),
								Type:          ptr.String("__Type__"),
								ImportedValue: ptr.String("__ImportedValue__"),
								ComponentName: ptr.String("__ComponentName__"),
								Property:      ptr.String("__Property__"),
							},
						},
					},
					BindingEvent: ptr.String("__BindingEvent__"),
				},
			},
			SchemaVersion: ptr.String("__SchemaVersion__"),
		},
	}
	status, header, body, err := serdeRespReadSnapshot("CreateComponent.response")
	if errors.Is(err, fs.ErrNotExist) {
		t.Skip("no response snapshot fixture")
	}
	if err != nil {
		t.Fatal(err)
	}
	svc := serdeRespClient(status, header, body)
	got, err := svc.CreateComponent(context.Background(), &CreateComponentInput{})
	if err != nil {
		t.Fatal(err)
	}
	if err := smithytesting.CompareValues(want, got); err != nil {
		t.Errorf("response snapshot mismatch for %s: %v", "CreateComponent.response", err)
	}
}

func TestCheckResponseSnapshot_CreateForm(t *testing.T) {
	want := &CreateFormOutput{
		Entity: &types.Form{
			AppId:           ptr.String("__AppId__"),
			EnvironmentName: ptr.String("__EnvironmentName__"),
			Id:              ptr.String("__Id__"),
			Name:            ptr.String("__Name__"),
			FormActionType:  types.FormActionType("create"),
			Style: &types.FormStyle{
				HorizontalGap: &types.FormStyleConfigMemberTokenReference{
					Value: "__FormStyleConfigMemberTokenReference__",
				},
				VerticalGap: &types.FormStyleConfigMemberTokenReference{
					Value: "__FormStyleConfigMemberTokenReference__",
				},
				OuterPadding: &types.FormStyleConfigMemberTokenReference{
					Value: "__FormStyleConfigMemberTokenReference__",
				},
			},
			DataType: &types.FormDataTypeConfig{
				DataSourceType: types.FormDataSourceType("DataStore"),
				DataTypeName:   ptr.String("__DataTypeName__"),
			},
			Fields: map[string]types.FieldConfig{
				"key0": {
					Label: ptr.String("__Label__"),
					Position: &types.FieldPositionMemberFixed{
						Value: types.FixedPosition("first"),
					},
					Excluded: ptr.Bool(true),
					InputType: &types.FieldInputConfig{
						Type:               ptr.String("__Type__"),
						Required:           ptr.Bool(true),
						ReadOnly:           ptr.Bool(true),
						Placeholder:        ptr.String("__Placeholder__"),
						DefaultValue:       ptr.String("__DefaultValue__"),
						DescriptiveText:    ptr.String("__DescriptiveText__"),
						DefaultChecked:     ptr.Bool(true),
						DefaultCountryCode: ptr.String("__DefaultCountryCode__"),
						ValueMappings: &types.ValueMappings{
							Values: []types.ValueMapping{
								{
									DisplayValue: &types.FormInputValueProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.FormInputValuePropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										Concat: []types.FormInputValueProperty{
											{},
											{},
										},
									},
									Value: &types.FormInputValueProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.FormInputValuePropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										Concat: []types.FormInputValueProperty{
											{},
											{},
										},
									},
								},
								{
									DisplayValue: &types.FormInputValueProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.FormInputValuePropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										Concat: []types.FormInputValueProperty{
											{},
											{},
										},
									},
									Value: &types.FormInputValueProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.FormInputValuePropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										Concat: []types.FormInputValueProperty{
											{},
											{},
										},
									},
								},
							},
							BindingProperties: map[string]types.FormInputBindingPropertiesValue{
								"key0": {
									Type: ptr.String("__Type__"),
									BindingProperties: &types.FormInputBindingPropertiesValueProperties{
										Model: ptr.String("__Model__"),
									},
								},
							},
						},
						Name:     ptr.String("__Name__"),
						MinValue: ptr.Float32(1.0),
						MaxValue: ptr.Float32(1.0),
						Step:     ptr.Float32(1.0),
						Value:    ptr.String("__Value__"),
						IsArray:  ptr.Bool(true),
						FileUploaderConfig: &types.FileUploaderFieldConfig{
							AccessLevel: types.StorageAccessLevel("public"),
							AcceptedFileTypes: []string{
								"__Member__",
								"__Member__",
							},
							ShowThumbnails: ptr.Bool(true),
							IsResumable:    ptr.Bool(true),
							MaxFileCount:   ptr.Int32(1),
							MaxSize:        ptr.Int32(1),
						},
					},
					Validations: []types.FieldValidationConfiguration{
						{
							Type: ptr.String("__Type__"),
							StrValues: []string{
								"__Member__",
								"__Member__",
							},
							NumValues: []int32{
								1,
								1,
							},
							ValidationMessage: ptr.String("__ValidationMessage__"),
						},
						{
							Type: ptr.String("__Type__"),
							StrValues: []string{
								"__Member__",
								"__Member__",
							},
							NumValues: []int32{
								1,
								1,
							},
							ValidationMessage: ptr.String("__ValidationMessage__"),
						},
					},
				},
			},
			SectionalElements: map[string]types.SectionalElement{
				"key0": {
					Type: ptr.String("__Type__"),
					Position: &types.FieldPositionMemberFixed{
						Value: types.FixedPosition("first"),
					},
					Text:        ptr.String("__Text__"),
					Level:       ptr.Int32(1),
					Orientation: ptr.String("__Orientation__"),
					Excluded:    ptr.Bool(true),
				},
			},
			SchemaVersion: ptr.String("__SchemaVersion__"),
			Tags: map[string]string{
				"key0": "__Value__",
			},
			Cta: &types.FormCTA{
				Position: types.FormButtonsPosition("top"),
				Clear: &types.FormButton{
					Excluded: ptr.Bool(true),
					Children: ptr.String("__Children__"),
					Position: &types.FieldPositionMemberFixed{
						Value: types.FixedPosition("first"),
					},
				},
				Cancel: &types.FormButton{
					Excluded: ptr.Bool(true),
					Children: ptr.String("__Children__"),
					Position: &types.FieldPositionMemberFixed{
						Value: types.FixedPosition("first"),
					},
				},
				Submit: &types.FormButton{
					Excluded: ptr.Bool(true),
					Children: ptr.String("__Children__"),
					Position: &types.FieldPositionMemberFixed{
						Value: types.FixedPosition("first"),
					},
				},
			},
			LabelDecorator: types.LabelDecorator("required"),
		},
	}
	status, header, body, err := serdeRespReadSnapshot("CreateForm.response")
	if errors.Is(err, fs.ErrNotExist) {
		t.Skip("no response snapshot fixture")
	}
	if err != nil {
		t.Fatal(err)
	}
	svc := serdeRespClient(status, header, body)
	got, err := svc.CreateForm(context.Background(), &CreateFormInput{})
	if err != nil {
		t.Fatal(err)
	}
	if err := smithytesting.CompareValues(want, got); err != nil {
		t.Errorf("response snapshot mismatch for %s: %v", "CreateForm.response", err)
	}
}

func TestCheckResponseSnapshot_CreateTheme(t *testing.T) {
	want := &CreateThemeOutput{
		Entity: &types.Theme{
			AppId:           ptr.String("__AppId__"),
			EnvironmentName: ptr.String("__EnvironmentName__"),
			Id:              ptr.String("__Id__"),
			Name:            ptr.String("__Name__"),
			CreatedAt:       ptr.Time(time.Date(2000, 1, 1, 0, 0, 0, 0, time.UTC)),
			ModifiedAt:      ptr.Time(time.Date(2000, 1, 1, 0, 0, 0, 0, time.UTC)),
			Values: []types.ThemeValues{
				{
					Key: ptr.String("__Key__"),
					Value: &types.ThemeValue{
						Value: ptr.String("__Value__"),
						Children: []types.ThemeValues{
							{},
							{},
						},
					},
				},
				{
					Key: ptr.String("__Key__"),
					Value: &types.ThemeValue{
						Value: ptr.String("__Value__"),
						Children: []types.ThemeValues{
							{},
							{},
						},
					},
				},
			},
			Overrides: []types.ThemeValues{
				{
					Key: ptr.String("__Key__"),
					Value: &types.ThemeValue{
						Value: ptr.String("__Value__"),
						Children: []types.ThemeValues{
							{},
							{},
						},
					},
				},
				{
					Key: ptr.String("__Key__"),
					Value: &types.ThemeValue{
						Value: ptr.String("__Value__"),
						Children: []types.ThemeValues{
							{},
							{},
						},
					},
				},
			},
			Tags: map[string]string{
				"key0": "__Value__",
			},
		},
	}
	status, header, body, err := serdeRespReadSnapshot("CreateTheme.response")
	if errors.Is(err, fs.ErrNotExist) {
		t.Skip("no response snapshot fixture")
	}
	if err != nil {
		t.Fatal(err)
	}
	svc := serdeRespClient(status, header, body)
	got, err := svc.CreateTheme(context.Background(), &CreateThemeInput{})
	if err != nil {
		t.Fatal(err)
	}
	if err := smithytesting.CompareValues(want, got); err != nil {
		t.Errorf("response snapshot mismatch for %s: %v", "CreateTheme.response", err)
	}
}

func TestCheckResponseSnapshot_DeleteComponent(t *testing.T) {
	want := &DeleteComponentOutput{}
	status, header, body, err := serdeRespReadSnapshot("DeleteComponent.response")
	if errors.Is(err, fs.ErrNotExist) {
		t.Skip("no response snapshot fixture")
	}
	if err != nil {
		t.Fatal(err)
	}
	svc := serdeRespClient(status, header, body)
	got, err := svc.DeleteComponent(context.Background(), &DeleteComponentInput{})
	if err != nil {
		t.Fatal(err)
	}
	if err := smithytesting.CompareValues(want, got); err != nil {
		t.Errorf("response snapshot mismatch for %s: %v", "DeleteComponent.response", err)
	}
}

func TestCheckResponseSnapshot_DeleteForm(t *testing.T) {
	want := &DeleteFormOutput{}
	status, header, body, err := serdeRespReadSnapshot("DeleteForm.response")
	if errors.Is(err, fs.ErrNotExist) {
		t.Skip("no response snapshot fixture")
	}
	if err != nil {
		t.Fatal(err)
	}
	svc := serdeRespClient(status, header, body)
	got, err := svc.DeleteForm(context.Background(), &DeleteFormInput{})
	if err != nil {
		t.Fatal(err)
	}
	if err := smithytesting.CompareValues(want, got); err != nil {
		t.Errorf("response snapshot mismatch for %s: %v", "DeleteForm.response", err)
	}
}

func TestCheckResponseSnapshot_DeleteTheme(t *testing.T) {
	want := &DeleteThemeOutput{}
	status, header, body, err := serdeRespReadSnapshot("DeleteTheme.response")
	if errors.Is(err, fs.ErrNotExist) {
		t.Skip("no response snapshot fixture")
	}
	if err != nil {
		t.Fatal(err)
	}
	svc := serdeRespClient(status, header, body)
	got, err := svc.DeleteTheme(context.Background(), &DeleteThemeInput{})
	if err != nil {
		t.Fatal(err)
	}
	if err := smithytesting.CompareValues(want, got); err != nil {
		t.Errorf("response snapshot mismatch for %s: %v", "DeleteTheme.response", err)
	}
}

func TestCheckResponseSnapshot_ExchangeCodeForToken(t *testing.T) {
	want := &ExchangeCodeForTokenOutput{
		AccessToken:  ptr.String("__AccessToken__"),
		ExpiresIn:    ptr.Int32(1),
		RefreshToken: ptr.String("__RefreshToken__"),
	}
	status, header, body, err := serdeRespReadSnapshot("ExchangeCodeForToken.response")
	if errors.Is(err, fs.ErrNotExist) {
		t.Skip("no response snapshot fixture")
	}
	if err != nil {
		t.Fatal(err)
	}
	svc := serdeRespClient(status, header, body)
	got, err := svc.ExchangeCodeForToken(context.Background(), &ExchangeCodeForTokenInput{})
	if err != nil {
		t.Fatal(err)
	}
	if err := smithytesting.CompareValues(want, got); err != nil {
		t.Errorf("response snapshot mismatch for %s: %v", "ExchangeCodeForToken.response", err)
	}
}

func TestCheckResponseSnapshot_ExportComponents(t *testing.T) {
	want := &ExportComponentsOutput{
		Entities: []types.Component{
			{
				AppId:           ptr.String("__AppId__"),
				EnvironmentName: ptr.String("__EnvironmentName__"),
				SourceId:        ptr.String("__SourceId__"),
				Id:              ptr.String("__Id__"),
				Name:            ptr.String("__Name__"),
				ComponentType:   ptr.String("__ComponentType__"),
				Properties: map[string]types.ComponentProperty{
					"key0": {
						Value: ptr.String("__Value__"),
						BindingProperties: &types.ComponentPropertyBindingProperties{
							Property: ptr.String("__Property__"),
							Field:    ptr.String("__Field__"),
						},
						CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
							Property: ptr.String("__Property__"),
							Field:    ptr.String("__Field__"),
						},
						DefaultValue: ptr.String("__DefaultValue__"),
						Model:        ptr.String("__Model__"),
						Bindings: map[string]types.FormBindingElement{
							"key0": {
								Element:  ptr.String("__Element__"),
								Property: ptr.String("__Property__"),
							},
						},
						Event:         ptr.String("__Event__"),
						UserAttribute: ptr.String("__UserAttribute__"),
						Concat: []types.ComponentProperty{
							{},
							{},
						},
						Condition: &types.ComponentConditionProperty{
							Property:    ptr.String("__Property__"),
							Field:       ptr.String("__Field__"),
							Operator:    ptr.String("__Operator__"),
							Operand:     ptr.String("__Operand__"),
							Then:        nil,
							Else:        nil,
							OperandType: ptr.String("__OperandType__"),
						},
						Configured:    ptr.Bool(true),
						Type:          ptr.String("__Type__"),
						ImportedValue: ptr.String("__ImportedValue__"),
						ComponentName: ptr.String("__ComponentName__"),
						Property:      ptr.String("__Property__"),
					},
				},
				Children: []types.ComponentChild{
					{
						ComponentType: ptr.String("__ComponentType__"),
						Name:          ptr.String("__Name__"),
						Properties: map[string]types.ComponentProperty{
							"key0": {
								Value: ptr.String("__Value__"),
								BindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								DefaultValue: ptr.String("__DefaultValue__"),
								Model:        ptr.String("__Model__"),
								Bindings: map[string]types.FormBindingElement{
									"key0": {
										Element:  ptr.String("__Element__"),
										Property: ptr.String("__Property__"),
									},
								},
								Event:         ptr.String("__Event__"),
								UserAttribute: ptr.String("__UserAttribute__"),
								Concat: []types.ComponentProperty{
									{},
									{},
								},
								Condition: &types.ComponentConditionProperty{
									Property:    ptr.String("__Property__"),
									Field:       ptr.String("__Field__"),
									Operator:    ptr.String("__Operator__"),
									Operand:     ptr.String("__Operand__"),
									Then:        nil,
									Else:        nil,
									OperandType: ptr.String("__OperandType__"),
								},
								Configured:    ptr.Bool(true),
								Type:          ptr.String("__Type__"),
								ImportedValue: ptr.String("__ImportedValue__"),
								ComponentName: ptr.String("__ComponentName__"),
								Property:      ptr.String("__Property__"),
							},
						},
						Children: []types.ComponentChild{
							{},
							{},
						},
						Events: map[string]types.ComponentEvent{
							"key0": {
								Action: ptr.String("__Action__"),
								Parameters: &types.ActionParameters{
									Type: &types.ComponentProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
									Url: &types.ComponentProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
									Anchor: &types.ComponentProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
									Target: &types.ComponentProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
									Global: &types.ComponentProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
									Model: ptr.String("__Model__"),
									Id: &types.ComponentProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
									Fields: map[string]types.ComponentProperty{
										"key0": {
											Value: ptr.String("__Value__"),
											BindingProperties: &types.ComponentPropertyBindingProperties{
												Property: ptr.String("__Property__"),
												Field:    ptr.String("__Field__"),
											},
											CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
												Property: ptr.String("__Property__"),
												Field:    ptr.String("__Field__"),
											},
											DefaultValue: ptr.String("__DefaultValue__"),
											Model:        ptr.String("__Model__"),
											Bindings: map[string]types.FormBindingElement{
												"key0": {
													Element:  ptr.String("__Element__"),
													Property: ptr.String("__Property__"),
												},
											},
											Event:         ptr.String("__Event__"),
											UserAttribute: ptr.String("__UserAttribute__"),
											Concat: []types.ComponentProperty{
												{},
												{},
											},
											Condition: &types.ComponentConditionProperty{
												Property:    ptr.String("__Property__"),
												Field:       ptr.String("__Field__"),
												Operator:    ptr.String("__Operator__"),
												Operand:     ptr.String("__Operand__"),
												Then:        nil,
												Else:        nil,
												OperandType: ptr.String("__OperandType__"),
											},
											Configured:    ptr.Bool(true),
											Type:          ptr.String("__Type__"),
											ImportedValue: ptr.String("__ImportedValue__"),
											ComponentName: ptr.String("__ComponentName__"),
											Property:      ptr.String("__Property__"),
										},
									},
									State: &types.MutationActionSetStateParameter{
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
										Set: &types.ComponentProperty{
											Value: ptr.String("__Value__"),
											BindingProperties: &types.ComponentPropertyBindingProperties{
												Property: ptr.String("__Property__"),
												Field:    ptr.String("__Field__"),
											},
											CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
												Property: ptr.String("__Property__"),
												Field:    ptr.String("__Field__"),
											},
											DefaultValue: ptr.String("__DefaultValue__"),
											Model:        ptr.String("__Model__"),
											Bindings: map[string]types.FormBindingElement{
												"key0": {
													Element:  ptr.String("__Element__"),
													Property: ptr.String("__Property__"),
												},
											},
											Event:         ptr.String("__Event__"),
											UserAttribute: ptr.String("__UserAttribute__"),
											Concat: []types.ComponentProperty{
												{},
												{},
											},
											Condition: &types.ComponentConditionProperty{
												Property:    ptr.String("__Property__"),
												Field:       ptr.String("__Field__"),
												Operator:    ptr.String("__Operator__"),
												Operand:     ptr.String("__Operand__"),
												Then:        nil,
												Else:        nil,
												OperandType: ptr.String("__OperandType__"),
											},
											Configured:    ptr.Bool(true),
											Type:          ptr.String("__Type__"),
											ImportedValue: ptr.String("__ImportedValue__"),
											ComponentName: ptr.String("__ComponentName__"),
											Property:      ptr.String("__Property__"),
										},
									},
								},
								BindingEvent: ptr.String("__BindingEvent__"),
							},
						},
						SourceId: ptr.String("__SourceId__"),
					},
					{
						ComponentType: ptr.String("__ComponentType__"),
						Name:          ptr.String("__Name__"),
						Properties: map[string]types.ComponentProperty{
							"key0": {
								Value: ptr.String("__Value__"),
								BindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								DefaultValue: ptr.String("__DefaultValue__"),
								Model:        ptr.String("__Model__"),
								Bindings: map[string]types.FormBindingElement{
									"key0": {
										Element:  ptr.String("__Element__"),
										Property: ptr.String("__Property__"),
									},
								},
								Event:         ptr.String("__Event__"),
								UserAttribute: ptr.String("__UserAttribute__"),
								Concat: []types.ComponentProperty{
									{},
									{},
								},
								Condition: &types.ComponentConditionProperty{
									Property:    ptr.String("__Property__"),
									Field:       ptr.String("__Field__"),
									Operator:    ptr.String("__Operator__"),
									Operand:     ptr.String("__Operand__"),
									Then:        nil,
									Else:        nil,
									OperandType: ptr.String("__OperandType__"),
								},
								Configured:    ptr.Bool(true),
								Type:          ptr.String("__Type__"),
								ImportedValue: ptr.String("__ImportedValue__"),
								ComponentName: ptr.String("__ComponentName__"),
								Property:      ptr.String("__Property__"),
							},
						},
						Children: []types.ComponentChild{
							{},
							{},
						},
						Events: map[string]types.ComponentEvent{
							"key0": {
								Action: ptr.String("__Action__"),
								Parameters: &types.ActionParameters{
									Type: &types.ComponentProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
									Url: &types.ComponentProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
									Anchor: &types.ComponentProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
									Target: &types.ComponentProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
									Global: &types.ComponentProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
									Model: ptr.String("__Model__"),
									Id: &types.ComponentProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
									Fields: map[string]types.ComponentProperty{
										"key0": {
											Value: ptr.String("__Value__"),
											BindingProperties: &types.ComponentPropertyBindingProperties{
												Property: ptr.String("__Property__"),
												Field:    ptr.String("__Field__"),
											},
											CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
												Property: ptr.String("__Property__"),
												Field:    ptr.String("__Field__"),
											},
											DefaultValue: ptr.String("__DefaultValue__"),
											Model:        ptr.String("__Model__"),
											Bindings: map[string]types.FormBindingElement{
												"key0": {
													Element:  ptr.String("__Element__"),
													Property: ptr.String("__Property__"),
												},
											},
											Event:         ptr.String("__Event__"),
											UserAttribute: ptr.String("__UserAttribute__"),
											Concat: []types.ComponentProperty{
												{},
												{},
											},
											Condition: &types.ComponentConditionProperty{
												Property:    ptr.String("__Property__"),
												Field:       ptr.String("__Field__"),
												Operator:    ptr.String("__Operator__"),
												Operand:     ptr.String("__Operand__"),
												Then:        nil,
												Else:        nil,
												OperandType: ptr.String("__OperandType__"),
											},
											Configured:    ptr.Bool(true),
											Type:          ptr.String("__Type__"),
											ImportedValue: ptr.String("__ImportedValue__"),
											ComponentName: ptr.String("__ComponentName__"),
											Property:      ptr.String("__Property__"),
										},
									},
									State: &types.MutationActionSetStateParameter{
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
										Set: &types.ComponentProperty{
											Value: ptr.String("__Value__"),
											BindingProperties: &types.ComponentPropertyBindingProperties{
												Property: ptr.String("__Property__"),
												Field:    ptr.String("__Field__"),
											},
											CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
												Property: ptr.String("__Property__"),
												Field:    ptr.String("__Field__"),
											},
											DefaultValue: ptr.String("__DefaultValue__"),
											Model:        ptr.String("__Model__"),
											Bindings: map[string]types.FormBindingElement{
												"key0": {
													Element:  ptr.String("__Element__"),
													Property: ptr.String("__Property__"),
												},
											},
											Event:         ptr.String("__Event__"),
											UserAttribute: ptr.String("__UserAttribute__"),
											Concat: []types.ComponentProperty{
												{},
												{},
											},
											Condition: &types.ComponentConditionProperty{
												Property:    ptr.String("__Property__"),
												Field:       ptr.String("__Field__"),
												Operator:    ptr.String("__Operator__"),
												Operand:     ptr.String("__Operand__"),
												Then:        nil,
												Else:        nil,
												OperandType: ptr.String("__OperandType__"),
											},
											Configured:    ptr.Bool(true),
											Type:          ptr.String("__Type__"),
											ImportedValue: ptr.String("__ImportedValue__"),
											ComponentName: ptr.String("__ComponentName__"),
											Property:      ptr.String("__Property__"),
										},
									},
								},
								BindingEvent: ptr.String("__BindingEvent__"),
							},
						},
						SourceId: ptr.String("__SourceId__"),
					},
				},
				Variants: []types.ComponentVariant{
					{
						VariantValues: map[string]string{
							"key0": "__Value__",
						},
						Overrides: map[string]map[string]string{
							"key0": {
								"key0": "__Value__",
							},
						},
					},
					{
						VariantValues: map[string]string{
							"key0": "__Value__",
						},
						Overrides: map[string]map[string]string{
							"key0": {
								"key0": "__Value__",
							},
						},
					},
				},
				Overrides: map[string]map[string]string{
					"key0": {
						"key0": "__Value__",
					},
				},
				BindingProperties: map[string]types.ComponentBindingPropertiesValue{
					"key0": {
						Type: ptr.String("__Type__"),
						BindingProperties: &types.ComponentBindingPropertiesValueProperties{
							Model: ptr.String("__Model__"),
							Field: ptr.String("__Field__"),
							Predicates: []types.Predicate{
								{
									Or: []types.Predicate{
										{},
										{},
									},
									And: []types.Predicate{
										{},
										{},
									},
									Field:       ptr.String("__Field__"),
									Operator:    ptr.String("__Operator__"),
									Operand:     ptr.String("__Operand__"),
									OperandType: ptr.String("__OperandType__"),
								},
								{
									Or: []types.Predicate{
										{},
										{},
									},
									And: []types.Predicate{
										{},
										{},
									},
									Field:       ptr.String("__Field__"),
									Operator:    ptr.String("__Operator__"),
									Operand:     ptr.String("__Operand__"),
									OperandType: ptr.String("__OperandType__"),
								},
							},
							UserAttribute: ptr.String("__UserAttribute__"),
							Bucket:        ptr.String("__Bucket__"),
							Key:           ptr.String("__Key__"),
							DefaultValue:  ptr.String("__DefaultValue__"),
							SlotName:      ptr.String("__SlotName__"),
						},
						DefaultValue: ptr.String("__DefaultValue__"),
					},
				},
				CollectionProperties: map[string]types.ComponentDataConfiguration{
					"key0": {
						Model: ptr.String("__Model__"),
						Sort: []types.SortProperty{
							{
								Field:     ptr.String("__Field__"),
								Direction: types.SortDirection("ASC"),
							},
							{
								Field:     ptr.String("__Field__"),
								Direction: types.SortDirection("ASC"),
							},
						},
						Predicate: &types.Predicate{
							Or: []types.Predicate{
								{},
								{},
							},
							And: []types.Predicate{
								{},
								{},
							},
							Field:       ptr.String("__Field__"),
							Operator:    ptr.String("__Operator__"),
							Operand:     ptr.String("__Operand__"),
							OperandType: ptr.String("__OperandType__"),
						},
						Identifiers: []string{
							"__Member__",
							"__Member__",
						},
					},
				},
				CreatedAt:  ptr.Time(time.Date(2000, 1, 1, 0, 0, 0, 0, time.UTC)),
				ModifiedAt: ptr.Time(time.Date(2000, 1, 1, 0, 0, 0, 0, time.UTC)),
				Tags: map[string]string{
					"key0": "__Value__",
				},
				Events: map[string]types.ComponentEvent{
					"key0": {
						Action: ptr.String("__Action__"),
						Parameters: &types.ActionParameters{
							Type: &types.ComponentProperty{
								Value: ptr.String("__Value__"),
								BindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								DefaultValue: ptr.String("__DefaultValue__"),
								Model:        ptr.String("__Model__"),
								Bindings: map[string]types.FormBindingElement{
									"key0": {
										Element:  ptr.String("__Element__"),
										Property: ptr.String("__Property__"),
									},
								},
								Event:         ptr.String("__Event__"),
								UserAttribute: ptr.String("__UserAttribute__"),
								Concat: []types.ComponentProperty{
									{},
									{},
								},
								Condition: &types.ComponentConditionProperty{
									Property:    ptr.String("__Property__"),
									Field:       ptr.String("__Field__"),
									Operator:    ptr.String("__Operator__"),
									Operand:     ptr.String("__Operand__"),
									Then:        nil,
									Else:        nil,
									OperandType: ptr.String("__OperandType__"),
								},
								Configured:    ptr.Bool(true),
								Type:          ptr.String("__Type__"),
								ImportedValue: ptr.String("__ImportedValue__"),
								ComponentName: ptr.String("__ComponentName__"),
								Property:      ptr.String("__Property__"),
							},
							Url: &types.ComponentProperty{
								Value: ptr.String("__Value__"),
								BindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								DefaultValue: ptr.String("__DefaultValue__"),
								Model:        ptr.String("__Model__"),
								Bindings: map[string]types.FormBindingElement{
									"key0": {
										Element:  ptr.String("__Element__"),
										Property: ptr.String("__Property__"),
									},
								},
								Event:         ptr.String("__Event__"),
								UserAttribute: ptr.String("__UserAttribute__"),
								Concat: []types.ComponentProperty{
									{},
									{},
								},
								Condition: &types.ComponentConditionProperty{
									Property:    ptr.String("__Property__"),
									Field:       ptr.String("__Field__"),
									Operator:    ptr.String("__Operator__"),
									Operand:     ptr.String("__Operand__"),
									Then:        nil,
									Else:        nil,
									OperandType: ptr.String("__OperandType__"),
								},
								Configured:    ptr.Bool(true),
								Type:          ptr.String("__Type__"),
								ImportedValue: ptr.String("__ImportedValue__"),
								ComponentName: ptr.String("__ComponentName__"),
								Property:      ptr.String("__Property__"),
							},
							Anchor: &types.ComponentProperty{
								Value: ptr.String("__Value__"),
								BindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								DefaultValue: ptr.String("__DefaultValue__"),
								Model:        ptr.String("__Model__"),
								Bindings: map[string]types.FormBindingElement{
									"key0": {
										Element:  ptr.String("__Element__"),
										Property: ptr.String("__Property__"),
									},
								},
								Event:         ptr.String("__Event__"),
								UserAttribute: ptr.String("__UserAttribute__"),
								Concat: []types.ComponentProperty{
									{},
									{},
								},
								Condition: &types.ComponentConditionProperty{
									Property:    ptr.String("__Property__"),
									Field:       ptr.String("__Field__"),
									Operator:    ptr.String("__Operator__"),
									Operand:     ptr.String("__Operand__"),
									Then:        nil,
									Else:        nil,
									OperandType: ptr.String("__OperandType__"),
								},
								Configured:    ptr.Bool(true),
								Type:          ptr.String("__Type__"),
								ImportedValue: ptr.String("__ImportedValue__"),
								ComponentName: ptr.String("__ComponentName__"),
								Property:      ptr.String("__Property__"),
							},
							Target: &types.ComponentProperty{
								Value: ptr.String("__Value__"),
								BindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								DefaultValue: ptr.String("__DefaultValue__"),
								Model:        ptr.String("__Model__"),
								Bindings: map[string]types.FormBindingElement{
									"key0": {
										Element:  ptr.String("__Element__"),
										Property: ptr.String("__Property__"),
									},
								},
								Event:         ptr.String("__Event__"),
								UserAttribute: ptr.String("__UserAttribute__"),
								Concat: []types.ComponentProperty{
									{},
									{},
								},
								Condition: &types.ComponentConditionProperty{
									Property:    ptr.String("__Property__"),
									Field:       ptr.String("__Field__"),
									Operator:    ptr.String("__Operator__"),
									Operand:     ptr.String("__Operand__"),
									Then:        nil,
									Else:        nil,
									OperandType: ptr.String("__OperandType__"),
								},
								Configured:    ptr.Bool(true),
								Type:          ptr.String("__Type__"),
								ImportedValue: ptr.String("__ImportedValue__"),
								ComponentName: ptr.String("__ComponentName__"),
								Property:      ptr.String("__Property__"),
							},
							Global: &types.ComponentProperty{
								Value: ptr.String("__Value__"),
								BindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								DefaultValue: ptr.String("__DefaultValue__"),
								Model:        ptr.String("__Model__"),
								Bindings: map[string]types.FormBindingElement{
									"key0": {
										Element:  ptr.String("__Element__"),
										Property: ptr.String("__Property__"),
									},
								},
								Event:         ptr.String("__Event__"),
								UserAttribute: ptr.String("__UserAttribute__"),
								Concat: []types.ComponentProperty{
									{},
									{},
								},
								Condition: &types.ComponentConditionProperty{
									Property:    ptr.String("__Property__"),
									Field:       ptr.String("__Field__"),
									Operator:    ptr.String("__Operator__"),
									Operand:     ptr.String("__Operand__"),
									Then:        nil,
									Else:        nil,
									OperandType: ptr.String("__OperandType__"),
								},
								Configured:    ptr.Bool(true),
								Type:          ptr.String("__Type__"),
								ImportedValue: ptr.String("__ImportedValue__"),
								ComponentName: ptr.String("__ComponentName__"),
								Property:      ptr.String("__Property__"),
							},
							Model: ptr.String("__Model__"),
							Id: &types.ComponentProperty{
								Value: ptr.String("__Value__"),
								BindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								DefaultValue: ptr.String("__DefaultValue__"),
								Model:        ptr.String("__Model__"),
								Bindings: map[string]types.FormBindingElement{
									"key0": {
										Element:  ptr.String("__Element__"),
										Property: ptr.String("__Property__"),
									},
								},
								Event:         ptr.String("__Event__"),
								UserAttribute: ptr.String("__UserAttribute__"),
								Concat: []types.ComponentProperty{
									{},
									{},
								},
								Condition: &types.ComponentConditionProperty{
									Property:    ptr.String("__Property__"),
									Field:       ptr.String("__Field__"),
									Operator:    ptr.String("__Operator__"),
									Operand:     ptr.String("__Operand__"),
									Then:        nil,
									Else:        nil,
									OperandType: ptr.String("__OperandType__"),
								},
								Configured:    ptr.Bool(true),
								Type:          ptr.String("__Type__"),
								ImportedValue: ptr.String("__ImportedValue__"),
								ComponentName: ptr.String("__ComponentName__"),
								Property:      ptr.String("__Property__"),
							},
							Fields: map[string]types.ComponentProperty{
								"key0": {
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
							},
							State: &types.MutationActionSetStateParameter{
								ComponentName: ptr.String("__ComponentName__"),
								Property:      ptr.String("__Property__"),
								Set: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
							},
						},
						BindingEvent: ptr.String("__BindingEvent__"),
					},
				},
				SchemaVersion: ptr.String("__SchemaVersion__"),
			},
			{
				AppId:           ptr.String("__AppId__"),
				EnvironmentName: ptr.String("__EnvironmentName__"),
				SourceId:        ptr.String("__SourceId__"),
				Id:              ptr.String("__Id__"),
				Name:            ptr.String("__Name__"),
				ComponentType:   ptr.String("__ComponentType__"),
				Properties: map[string]types.ComponentProperty{
					"key0": {
						Value: ptr.String("__Value__"),
						BindingProperties: &types.ComponentPropertyBindingProperties{
							Property: ptr.String("__Property__"),
							Field:    ptr.String("__Field__"),
						},
						CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
							Property: ptr.String("__Property__"),
							Field:    ptr.String("__Field__"),
						},
						DefaultValue: ptr.String("__DefaultValue__"),
						Model:        ptr.String("__Model__"),
						Bindings: map[string]types.FormBindingElement{
							"key0": {
								Element:  ptr.String("__Element__"),
								Property: ptr.String("__Property__"),
							},
						},
						Event:         ptr.String("__Event__"),
						UserAttribute: ptr.String("__UserAttribute__"),
						Concat: []types.ComponentProperty{
							{},
							{},
						},
						Condition: &types.ComponentConditionProperty{
							Property:    ptr.String("__Property__"),
							Field:       ptr.String("__Field__"),
							Operator:    ptr.String("__Operator__"),
							Operand:     ptr.String("__Operand__"),
							Then:        nil,
							Else:        nil,
							OperandType: ptr.String("__OperandType__"),
						},
						Configured:    ptr.Bool(true),
						Type:          ptr.String("__Type__"),
						ImportedValue: ptr.String("__ImportedValue__"),
						ComponentName: ptr.String("__ComponentName__"),
						Property:      ptr.String("__Property__"),
					},
				},
				Children: []types.ComponentChild{
					{
						ComponentType: ptr.String("__ComponentType__"),
						Name:          ptr.String("__Name__"),
						Properties: map[string]types.ComponentProperty{
							"key0": {
								Value: ptr.String("__Value__"),
								BindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								DefaultValue: ptr.String("__DefaultValue__"),
								Model:        ptr.String("__Model__"),
								Bindings: map[string]types.FormBindingElement{
									"key0": {
										Element:  ptr.String("__Element__"),
										Property: ptr.String("__Property__"),
									},
								},
								Event:         ptr.String("__Event__"),
								UserAttribute: ptr.String("__UserAttribute__"),
								Concat: []types.ComponentProperty{
									{},
									{},
								},
								Condition: &types.ComponentConditionProperty{
									Property:    ptr.String("__Property__"),
									Field:       ptr.String("__Field__"),
									Operator:    ptr.String("__Operator__"),
									Operand:     ptr.String("__Operand__"),
									Then:        nil,
									Else:        nil,
									OperandType: ptr.String("__OperandType__"),
								},
								Configured:    ptr.Bool(true),
								Type:          ptr.String("__Type__"),
								ImportedValue: ptr.String("__ImportedValue__"),
								ComponentName: ptr.String("__ComponentName__"),
								Property:      ptr.String("__Property__"),
							},
						},
						Children: []types.ComponentChild{
							{},
							{},
						},
						Events: map[string]types.ComponentEvent{
							"key0": {
								Action: ptr.String("__Action__"),
								Parameters: &types.ActionParameters{
									Type: &types.ComponentProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
									Url: &types.ComponentProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
									Anchor: &types.ComponentProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
									Target: &types.ComponentProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
									Global: &types.ComponentProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
									Model: ptr.String("__Model__"),
									Id: &types.ComponentProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
									Fields: map[string]types.ComponentProperty{
										"key0": {
											Value: ptr.String("__Value__"),
											BindingProperties: &types.ComponentPropertyBindingProperties{
												Property: ptr.String("__Property__"),
												Field:    ptr.String("__Field__"),
											},
											CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
												Property: ptr.String("__Property__"),
												Field:    ptr.String("__Field__"),
											},
											DefaultValue: ptr.String("__DefaultValue__"),
											Model:        ptr.String("__Model__"),
											Bindings: map[string]types.FormBindingElement{
												"key0": {
													Element:  ptr.String("__Element__"),
													Property: ptr.String("__Property__"),
												},
											},
											Event:         ptr.String("__Event__"),
											UserAttribute: ptr.String("__UserAttribute__"),
											Concat: []types.ComponentProperty{
												{},
												{},
											},
											Condition: &types.ComponentConditionProperty{
												Property:    ptr.String("__Property__"),
												Field:       ptr.String("__Field__"),
												Operator:    ptr.String("__Operator__"),
												Operand:     ptr.String("__Operand__"),
												Then:        nil,
												Else:        nil,
												OperandType: ptr.String("__OperandType__"),
											},
											Configured:    ptr.Bool(true),
											Type:          ptr.String("__Type__"),
											ImportedValue: ptr.String("__ImportedValue__"),
											ComponentName: ptr.String("__ComponentName__"),
											Property:      ptr.String("__Property__"),
										},
									},
									State: &types.MutationActionSetStateParameter{
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
										Set: &types.ComponentProperty{
											Value: ptr.String("__Value__"),
											BindingProperties: &types.ComponentPropertyBindingProperties{
												Property: ptr.String("__Property__"),
												Field:    ptr.String("__Field__"),
											},
											CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
												Property: ptr.String("__Property__"),
												Field:    ptr.String("__Field__"),
											},
											DefaultValue: ptr.String("__DefaultValue__"),
											Model:        ptr.String("__Model__"),
											Bindings: map[string]types.FormBindingElement{
												"key0": {
													Element:  ptr.String("__Element__"),
													Property: ptr.String("__Property__"),
												},
											},
											Event:         ptr.String("__Event__"),
											UserAttribute: ptr.String("__UserAttribute__"),
											Concat: []types.ComponentProperty{
												{},
												{},
											},
											Condition: &types.ComponentConditionProperty{
												Property:    ptr.String("__Property__"),
												Field:       ptr.String("__Field__"),
												Operator:    ptr.String("__Operator__"),
												Operand:     ptr.String("__Operand__"),
												Then:        nil,
												Else:        nil,
												OperandType: ptr.String("__OperandType__"),
											},
											Configured:    ptr.Bool(true),
											Type:          ptr.String("__Type__"),
											ImportedValue: ptr.String("__ImportedValue__"),
											ComponentName: ptr.String("__ComponentName__"),
											Property:      ptr.String("__Property__"),
										},
									},
								},
								BindingEvent: ptr.String("__BindingEvent__"),
							},
						},
						SourceId: ptr.String("__SourceId__"),
					},
					{
						ComponentType: ptr.String("__ComponentType__"),
						Name:          ptr.String("__Name__"),
						Properties: map[string]types.ComponentProperty{
							"key0": {
								Value: ptr.String("__Value__"),
								BindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								DefaultValue: ptr.String("__DefaultValue__"),
								Model:        ptr.String("__Model__"),
								Bindings: map[string]types.FormBindingElement{
									"key0": {
										Element:  ptr.String("__Element__"),
										Property: ptr.String("__Property__"),
									},
								},
								Event:         ptr.String("__Event__"),
								UserAttribute: ptr.String("__UserAttribute__"),
								Concat: []types.ComponentProperty{
									{},
									{},
								},
								Condition: &types.ComponentConditionProperty{
									Property:    ptr.String("__Property__"),
									Field:       ptr.String("__Field__"),
									Operator:    ptr.String("__Operator__"),
									Operand:     ptr.String("__Operand__"),
									Then:        nil,
									Else:        nil,
									OperandType: ptr.String("__OperandType__"),
								},
								Configured:    ptr.Bool(true),
								Type:          ptr.String("__Type__"),
								ImportedValue: ptr.String("__ImportedValue__"),
								ComponentName: ptr.String("__ComponentName__"),
								Property:      ptr.String("__Property__"),
							},
						},
						Children: []types.ComponentChild{
							{},
							{},
						},
						Events: map[string]types.ComponentEvent{
							"key0": {
								Action: ptr.String("__Action__"),
								Parameters: &types.ActionParameters{
									Type: &types.ComponentProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
									Url: &types.ComponentProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
									Anchor: &types.ComponentProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
									Target: &types.ComponentProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
									Global: &types.ComponentProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
									Model: ptr.String("__Model__"),
									Id: &types.ComponentProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
									Fields: map[string]types.ComponentProperty{
										"key0": {
											Value: ptr.String("__Value__"),
											BindingProperties: &types.ComponentPropertyBindingProperties{
												Property: ptr.String("__Property__"),
												Field:    ptr.String("__Field__"),
											},
											CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
												Property: ptr.String("__Property__"),
												Field:    ptr.String("__Field__"),
											},
											DefaultValue: ptr.String("__DefaultValue__"),
											Model:        ptr.String("__Model__"),
											Bindings: map[string]types.FormBindingElement{
												"key0": {
													Element:  ptr.String("__Element__"),
													Property: ptr.String("__Property__"),
												},
											},
											Event:         ptr.String("__Event__"),
											UserAttribute: ptr.String("__UserAttribute__"),
											Concat: []types.ComponentProperty{
												{},
												{},
											},
											Condition: &types.ComponentConditionProperty{
												Property:    ptr.String("__Property__"),
												Field:       ptr.String("__Field__"),
												Operator:    ptr.String("__Operator__"),
												Operand:     ptr.String("__Operand__"),
												Then:        nil,
												Else:        nil,
												OperandType: ptr.String("__OperandType__"),
											},
											Configured:    ptr.Bool(true),
											Type:          ptr.String("__Type__"),
											ImportedValue: ptr.String("__ImportedValue__"),
											ComponentName: ptr.String("__ComponentName__"),
											Property:      ptr.String("__Property__"),
										},
									},
									State: &types.MutationActionSetStateParameter{
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
										Set: &types.ComponentProperty{
											Value: ptr.String("__Value__"),
											BindingProperties: &types.ComponentPropertyBindingProperties{
												Property: ptr.String("__Property__"),
												Field:    ptr.String("__Field__"),
											},
											CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
												Property: ptr.String("__Property__"),
												Field:    ptr.String("__Field__"),
											},
											DefaultValue: ptr.String("__DefaultValue__"),
											Model:        ptr.String("__Model__"),
											Bindings: map[string]types.FormBindingElement{
												"key0": {
													Element:  ptr.String("__Element__"),
													Property: ptr.String("__Property__"),
												},
											},
											Event:         ptr.String("__Event__"),
											UserAttribute: ptr.String("__UserAttribute__"),
											Concat: []types.ComponentProperty{
												{},
												{},
											},
											Condition: &types.ComponentConditionProperty{
												Property:    ptr.String("__Property__"),
												Field:       ptr.String("__Field__"),
												Operator:    ptr.String("__Operator__"),
												Operand:     ptr.String("__Operand__"),
												Then:        nil,
												Else:        nil,
												OperandType: ptr.String("__OperandType__"),
											},
											Configured:    ptr.Bool(true),
											Type:          ptr.String("__Type__"),
											ImportedValue: ptr.String("__ImportedValue__"),
											ComponentName: ptr.String("__ComponentName__"),
											Property:      ptr.String("__Property__"),
										},
									},
								},
								BindingEvent: ptr.String("__BindingEvent__"),
							},
						},
						SourceId: ptr.String("__SourceId__"),
					},
				},
				Variants: []types.ComponentVariant{
					{
						VariantValues: map[string]string{
							"key0": "__Value__",
						},
						Overrides: map[string]map[string]string{
							"key0": {
								"key0": "__Value__",
							},
						},
					},
					{
						VariantValues: map[string]string{
							"key0": "__Value__",
						},
						Overrides: map[string]map[string]string{
							"key0": {
								"key0": "__Value__",
							},
						},
					},
				},
				Overrides: map[string]map[string]string{
					"key0": {
						"key0": "__Value__",
					},
				},
				BindingProperties: map[string]types.ComponentBindingPropertiesValue{
					"key0": {
						Type: ptr.String("__Type__"),
						BindingProperties: &types.ComponentBindingPropertiesValueProperties{
							Model: ptr.String("__Model__"),
							Field: ptr.String("__Field__"),
							Predicates: []types.Predicate{
								{
									Or: []types.Predicate{
										{},
										{},
									},
									And: []types.Predicate{
										{},
										{},
									},
									Field:       ptr.String("__Field__"),
									Operator:    ptr.String("__Operator__"),
									Operand:     ptr.String("__Operand__"),
									OperandType: ptr.String("__OperandType__"),
								},
								{
									Or: []types.Predicate{
										{},
										{},
									},
									And: []types.Predicate{
										{},
										{},
									},
									Field:       ptr.String("__Field__"),
									Operator:    ptr.String("__Operator__"),
									Operand:     ptr.String("__Operand__"),
									OperandType: ptr.String("__OperandType__"),
								},
							},
							UserAttribute: ptr.String("__UserAttribute__"),
							Bucket:        ptr.String("__Bucket__"),
							Key:           ptr.String("__Key__"),
							DefaultValue:  ptr.String("__DefaultValue__"),
							SlotName:      ptr.String("__SlotName__"),
						},
						DefaultValue: ptr.String("__DefaultValue__"),
					},
				},
				CollectionProperties: map[string]types.ComponentDataConfiguration{
					"key0": {
						Model: ptr.String("__Model__"),
						Sort: []types.SortProperty{
							{
								Field:     ptr.String("__Field__"),
								Direction: types.SortDirection("ASC"),
							},
							{
								Field:     ptr.String("__Field__"),
								Direction: types.SortDirection("ASC"),
							},
						},
						Predicate: &types.Predicate{
							Or: []types.Predicate{
								{},
								{},
							},
							And: []types.Predicate{
								{},
								{},
							},
							Field:       ptr.String("__Field__"),
							Operator:    ptr.String("__Operator__"),
							Operand:     ptr.String("__Operand__"),
							OperandType: ptr.String("__OperandType__"),
						},
						Identifiers: []string{
							"__Member__",
							"__Member__",
						},
					},
				},
				CreatedAt:  ptr.Time(time.Date(2000, 1, 1, 0, 0, 0, 0, time.UTC)),
				ModifiedAt: ptr.Time(time.Date(2000, 1, 1, 0, 0, 0, 0, time.UTC)),
				Tags: map[string]string{
					"key0": "__Value__",
				},
				Events: map[string]types.ComponentEvent{
					"key0": {
						Action: ptr.String("__Action__"),
						Parameters: &types.ActionParameters{
							Type: &types.ComponentProperty{
								Value: ptr.String("__Value__"),
								BindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								DefaultValue: ptr.String("__DefaultValue__"),
								Model:        ptr.String("__Model__"),
								Bindings: map[string]types.FormBindingElement{
									"key0": {
										Element:  ptr.String("__Element__"),
										Property: ptr.String("__Property__"),
									},
								},
								Event:         ptr.String("__Event__"),
								UserAttribute: ptr.String("__UserAttribute__"),
								Concat: []types.ComponentProperty{
									{},
									{},
								},
								Condition: &types.ComponentConditionProperty{
									Property:    ptr.String("__Property__"),
									Field:       ptr.String("__Field__"),
									Operator:    ptr.String("__Operator__"),
									Operand:     ptr.String("__Operand__"),
									Then:        nil,
									Else:        nil,
									OperandType: ptr.String("__OperandType__"),
								},
								Configured:    ptr.Bool(true),
								Type:          ptr.String("__Type__"),
								ImportedValue: ptr.String("__ImportedValue__"),
								ComponentName: ptr.String("__ComponentName__"),
								Property:      ptr.String("__Property__"),
							},
							Url: &types.ComponentProperty{
								Value: ptr.String("__Value__"),
								BindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								DefaultValue: ptr.String("__DefaultValue__"),
								Model:        ptr.String("__Model__"),
								Bindings: map[string]types.FormBindingElement{
									"key0": {
										Element:  ptr.String("__Element__"),
										Property: ptr.String("__Property__"),
									},
								},
								Event:         ptr.String("__Event__"),
								UserAttribute: ptr.String("__UserAttribute__"),
								Concat: []types.ComponentProperty{
									{},
									{},
								},
								Condition: &types.ComponentConditionProperty{
									Property:    ptr.String("__Property__"),
									Field:       ptr.String("__Field__"),
									Operator:    ptr.String("__Operator__"),
									Operand:     ptr.String("__Operand__"),
									Then:        nil,
									Else:        nil,
									OperandType: ptr.String("__OperandType__"),
								},
								Configured:    ptr.Bool(true),
								Type:          ptr.String("__Type__"),
								ImportedValue: ptr.String("__ImportedValue__"),
								ComponentName: ptr.String("__ComponentName__"),
								Property:      ptr.String("__Property__"),
							},
							Anchor: &types.ComponentProperty{
								Value: ptr.String("__Value__"),
								BindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								DefaultValue: ptr.String("__DefaultValue__"),
								Model:        ptr.String("__Model__"),
								Bindings: map[string]types.FormBindingElement{
									"key0": {
										Element:  ptr.String("__Element__"),
										Property: ptr.String("__Property__"),
									},
								},
								Event:         ptr.String("__Event__"),
								UserAttribute: ptr.String("__UserAttribute__"),
								Concat: []types.ComponentProperty{
									{},
									{},
								},
								Condition: &types.ComponentConditionProperty{
									Property:    ptr.String("__Property__"),
									Field:       ptr.String("__Field__"),
									Operator:    ptr.String("__Operator__"),
									Operand:     ptr.String("__Operand__"),
									Then:        nil,
									Else:        nil,
									OperandType: ptr.String("__OperandType__"),
								},
								Configured:    ptr.Bool(true),
								Type:          ptr.String("__Type__"),
								ImportedValue: ptr.String("__ImportedValue__"),
								ComponentName: ptr.String("__ComponentName__"),
								Property:      ptr.String("__Property__"),
							},
							Target: &types.ComponentProperty{
								Value: ptr.String("__Value__"),
								BindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								DefaultValue: ptr.String("__DefaultValue__"),
								Model:        ptr.String("__Model__"),
								Bindings: map[string]types.FormBindingElement{
									"key0": {
										Element:  ptr.String("__Element__"),
										Property: ptr.String("__Property__"),
									},
								},
								Event:         ptr.String("__Event__"),
								UserAttribute: ptr.String("__UserAttribute__"),
								Concat: []types.ComponentProperty{
									{},
									{},
								},
								Condition: &types.ComponentConditionProperty{
									Property:    ptr.String("__Property__"),
									Field:       ptr.String("__Field__"),
									Operator:    ptr.String("__Operator__"),
									Operand:     ptr.String("__Operand__"),
									Then:        nil,
									Else:        nil,
									OperandType: ptr.String("__OperandType__"),
								},
								Configured:    ptr.Bool(true),
								Type:          ptr.String("__Type__"),
								ImportedValue: ptr.String("__ImportedValue__"),
								ComponentName: ptr.String("__ComponentName__"),
								Property:      ptr.String("__Property__"),
							},
							Global: &types.ComponentProperty{
								Value: ptr.String("__Value__"),
								BindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								DefaultValue: ptr.String("__DefaultValue__"),
								Model:        ptr.String("__Model__"),
								Bindings: map[string]types.FormBindingElement{
									"key0": {
										Element:  ptr.String("__Element__"),
										Property: ptr.String("__Property__"),
									},
								},
								Event:         ptr.String("__Event__"),
								UserAttribute: ptr.String("__UserAttribute__"),
								Concat: []types.ComponentProperty{
									{},
									{},
								},
								Condition: &types.ComponentConditionProperty{
									Property:    ptr.String("__Property__"),
									Field:       ptr.String("__Field__"),
									Operator:    ptr.String("__Operator__"),
									Operand:     ptr.String("__Operand__"),
									Then:        nil,
									Else:        nil,
									OperandType: ptr.String("__OperandType__"),
								},
								Configured:    ptr.Bool(true),
								Type:          ptr.String("__Type__"),
								ImportedValue: ptr.String("__ImportedValue__"),
								ComponentName: ptr.String("__ComponentName__"),
								Property:      ptr.String("__Property__"),
							},
							Model: ptr.String("__Model__"),
							Id: &types.ComponentProperty{
								Value: ptr.String("__Value__"),
								BindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								DefaultValue: ptr.String("__DefaultValue__"),
								Model:        ptr.String("__Model__"),
								Bindings: map[string]types.FormBindingElement{
									"key0": {
										Element:  ptr.String("__Element__"),
										Property: ptr.String("__Property__"),
									},
								},
								Event:         ptr.String("__Event__"),
								UserAttribute: ptr.String("__UserAttribute__"),
								Concat: []types.ComponentProperty{
									{},
									{},
								},
								Condition: &types.ComponentConditionProperty{
									Property:    ptr.String("__Property__"),
									Field:       ptr.String("__Field__"),
									Operator:    ptr.String("__Operator__"),
									Operand:     ptr.String("__Operand__"),
									Then:        nil,
									Else:        nil,
									OperandType: ptr.String("__OperandType__"),
								},
								Configured:    ptr.Bool(true),
								Type:          ptr.String("__Type__"),
								ImportedValue: ptr.String("__ImportedValue__"),
								ComponentName: ptr.String("__ComponentName__"),
								Property:      ptr.String("__Property__"),
							},
							Fields: map[string]types.ComponentProperty{
								"key0": {
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
							},
							State: &types.MutationActionSetStateParameter{
								ComponentName: ptr.String("__ComponentName__"),
								Property:      ptr.String("__Property__"),
								Set: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
							},
						},
						BindingEvent: ptr.String("__BindingEvent__"),
					},
				},
				SchemaVersion: ptr.String("__SchemaVersion__"),
			},
		},
		NextToken: ptr.String("__NextToken__"),
	}
	status, header, body, err := serdeRespReadSnapshot("ExportComponents.response")
	if errors.Is(err, fs.ErrNotExist) {
		t.Skip("no response snapshot fixture")
	}
	if err != nil {
		t.Fatal(err)
	}
	svc := serdeRespClient(status, header, body)
	got, err := svc.ExportComponents(context.Background(), &ExportComponentsInput{})
	if err != nil {
		t.Fatal(err)
	}
	if err := smithytesting.CompareValues(want, got); err != nil {
		t.Errorf("response snapshot mismatch for %s: %v", "ExportComponents.response", err)
	}
}

func TestCheckResponseSnapshot_ExportForms(t *testing.T) {
	want := &ExportFormsOutput{
		Entities: []types.Form{
			{
				AppId:           ptr.String("__AppId__"),
				EnvironmentName: ptr.String("__EnvironmentName__"),
				Id:              ptr.String("__Id__"),
				Name:            ptr.String("__Name__"),
				FormActionType:  types.FormActionType("create"),
				Style: &types.FormStyle{
					HorizontalGap: &types.FormStyleConfigMemberTokenReference{
						Value: "__FormStyleConfigMemberTokenReference__",
					},
					VerticalGap: &types.FormStyleConfigMemberTokenReference{
						Value: "__FormStyleConfigMemberTokenReference__",
					},
					OuterPadding: &types.FormStyleConfigMemberTokenReference{
						Value: "__FormStyleConfigMemberTokenReference__",
					},
				},
				DataType: &types.FormDataTypeConfig{
					DataSourceType: types.FormDataSourceType("DataStore"),
					DataTypeName:   ptr.String("__DataTypeName__"),
				},
				Fields: map[string]types.FieldConfig{
					"key0": {
						Label: ptr.String("__Label__"),
						Position: &types.FieldPositionMemberFixed{
							Value: types.FixedPosition("first"),
						},
						Excluded: ptr.Bool(true),
						InputType: &types.FieldInputConfig{
							Type:               ptr.String("__Type__"),
							Required:           ptr.Bool(true),
							ReadOnly:           ptr.Bool(true),
							Placeholder:        ptr.String("__Placeholder__"),
							DefaultValue:       ptr.String("__DefaultValue__"),
							DescriptiveText:    ptr.String("__DescriptiveText__"),
							DefaultChecked:     ptr.Bool(true),
							DefaultCountryCode: ptr.String("__DefaultCountryCode__"),
							ValueMappings: &types.ValueMappings{
								Values: []types.ValueMapping{
									{
										DisplayValue: &types.FormInputValueProperty{
											Value: ptr.String("__Value__"),
											BindingProperties: &types.FormInputValuePropertyBindingProperties{
												Property: ptr.String("__Property__"),
												Field:    ptr.String("__Field__"),
											},
											Concat: []types.FormInputValueProperty{
												{},
												{},
											},
										},
										Value: &types.FormInputValueProperty{
											Value: ptr.String("__Value__"),
											BindingProperties: &types.FormInputValuePropertyBindingProperties{
												Property: ptr.String("__Property__"),
												Field:    ptr.String("__Field__"),
											},
											Concat: []types.FormInputValueProperty{
												{},
												{},
											},
										},
									},
									{
										DisplayValue: &types.FormInputValueProperty{
											Value: ptr.String("__Value__"),
											BindingProperties: &types.FormInputValuePropertyBindingProperties{
												Property: ptr.String("__Property__"),
												Field:    ptr.String("__Field__"),
											},
											Concat: []types.FormInputValueProperty{
												{},
												{},
											},
										},
										Value: &types.FormInputValueProperty{
											Value: ptr.String("__Value__"),
											BindingProperties: &types.FormInputValuePropertyBindingProperties{
												Property: ptr.String("__Property__"),
												Field:    ptr.String("__Field__"),
											},
											Concat: []types.FormInputValueProperty{
												{},
												{},
											},
										},
									},
								},
								BindingProperties: map[string]types.FormInputBindingPropertiesValue{
									"key0": {
										Type: ptr.String("__Type__"),
										BindingProperties: &types.FormInputBindingPropertiesValueProperties{
											Model: ptr.String("__Model__"),
										},
									},
								},
							},
							Name:     ptr.String("__Name__"),
							MinValue: ptr.Float32(1.0),
							MaxValue: ptr.Float32(1.0),
							Step:     ptr.Float32(1.0),
							Value:    ptr.String("__Value__"),
							IsArray:  ptr.Bool(true),
							FileUploaderConfig: &types.FileUploaderFieldConfig{
								AccessLevel: types.StorageAccessLevel("public"),
								AcceptedFileTypes: []string{
									"__Member__",
									"__Member__",
								},
								ShowThumbnails: ptr.Bool(true),
								IsResumable:    ptr.Bool(true),
								MaxFileCount:   ptr.Int32(1),
								MaxSize:        ptr.Int32(1),
							},
						},
						Validations: []types.FieldValidationConfiguration{
							{
								Type: ptr.String("__Type__"),
								StrValues: []string{
									"__Member__",
									"__Member__",
								},
								NumValues: []int32{
									1,
									1,
								},
								ValidationMessage: ptr.String("__ValidationMessage__"),
							},
							{
								Type: ptr.String("__Type__"),
								StrValues: []string{
									"__Member__",
									"__Member__",
								},
								NumValues: []int32{
									1,
									1,
								},
								ValidationMessage: ptr.String("__ValidationMessage__"),
							},
						},
					},
				},
				SectionalElements: map[string]types.SectionalElement{
					"key0": {
						Type: ptr.String("__Type__"),
						Position: &types.FieldPositionMemberFixed{
							Value: types.FixedPosition("first"),
						},
						Text:        ptr.String("__Text__"),
						Level:       ptr.Int32(1),
						Orientation: ptr.String("__Orientation__"),
						Excluded:    ptr.Bool(true),
					},
				},
				SchemaVersion: ptr.String("__SchemaVersion__"),
				Tags: map[string]string{
					"key0": "__Value__",
				},
				Cta: &types.FormCTA{
					Position: types.FormButtonsPosition("top"),
					Clear: &types.FormButton{
						Excluded: ptr.Bool(true),
						Children: ptr.String("__Children__"),
						Position: &types.FieldPositionMemberFixed{
							Value: types.FixedPosition("first"),
						},
					},
					Cancel: &types.FormButton{
						Excluded: ptr.Bool(true),
						Children: ptr.String("__Children__"),
						Position: &types.FieldPositionMemberFixed{
							Value: types.FixedPosition("first"),
						},
					},
					Submit: &types.FormButton{
						Excluded: ptr.Bool(true),
						Children: ptr.String("__Children__"),
						Position: &types.FieldPositionMemberFixed{
							Value: types.FixedPosition("first"),
						},
					},
				},
				LabelDecorator: types.LabelDecorator("required"),
			},
			{
				AppId:           ptr.String("__AppId__"),
				EnvironmentName: ptr.String("__EnvironmentName__"),
				Id:              ptr.String("__Id__"),
				Name:            ptr.String("__Name__"),
				FormActionType:  types.FormActionType("create"),
				Style: &types.FormStyle{
					HorizontalGap: &types.FormStyleConfigMemberTokenReference{
						Value: "__FormStyleConfigMemberTokenReference__",
					},
					VerticalGap: &types.FormStyleConfigMemberTokenReference{
						Value: "__FormStyleConfigMemberTokenReference__",
					},
					OuterPadding: &types.FormStyleConfigMemberTokenReference{
						Value: "__FormStyleConfigMemberTokenReference__",
					},
				},
				DataType: &types.FormDataTypeConfig{
					DataSourceType: types.FormDataSourceType("DataStore"),
					DataTypeName:   ptr.String("__DataTypeName__"),
				},
				Fields: map[string]types.FieldConfig{
					"key0": {
						Label: ptr.String("__Label__"),
						Position: &types.FieldPositionMemberFixed{
							Value: types.FixedPosition("first"),
						},
						Excluded: ptr.Bool(true),
						InputType: &types.FieldInputConfig{
							Type:               ptr.String("__Type__"),
							Required:           ptr.Bool(true),
							ReadOnly:           ptr.Bool(true),
							Placeholder:        ptr.String("__Placeholder__"),
							DefaultValue:       ptr.String("__DefaultValue__"),
							DescriptiveText:    ptr.String("__DescriptiveText__"),
							DefaultChecked:     ptr.Bool(true),
							DefaultCountryCode: ptr.String("__DefaultCountryCode__"),
							ValueMappings: &types.ValueMappings{
								Values: []types.ValueMapping{
									{
										DisplayValue: &types.FormInputValueProperty{
											Value: ptr.String("__Value__"),
											BindingProperties: &types.FormInputValuePropertyBindingProperties{
												Property: ptr.String("__Property__"),
												Field:    ptr.String("__Field__"),
											},
											Concat: []types.FormInputValueProperty{
												{},
												{},
											},
										},
										Value: &types.FormInputValueProperty{
											Value: ptr.String("__Value__"),
											BindingProperties: &types.FormInputValuePropertyBindingProperties{
												Property: ptr.String("__Property__"),
												Field:    ptr.String("__Field__"),
											},
											Concat: []types.FormInputValueProperty{
												{},
												{},
											},
										},
									},
									{
										DisplayValue: &types.FormInputValueProperty{
											Value: ptr.String("__Value__"),
											BindingProperties: &types.FormInputValuePropertyBindingProperties{
												Property: ptr.String("__Property__"),
												Field:    ptr.String("__Field__"),
											},
											Concat: []types.FormInputValueProperty{
												{},
												{},
											},
										},
										Value: &types.FormInputValueProperty{
											Value: ptr.String("__Value__"),
											BindingProperties: &types.FormInputValuePropertyBindingProperties{
												Property: ptr.String("__Property__"),
												Field:    ptr.String("__Field__"),
											},
											Concat: []types.FormInputValueProperty{
												{},
												{},
											},
										},
									},
								},
								BindingProperties: map[string]types.FormInputBindingPropertiesValue{
									"key0": {
										Type: ptr.String("__Type__"),
										BindingProperties: &types.FormInputBindingPropertiesValueProperties{
											Model: ptr.String("__Model__"),
										},
									},
								},
							},
							Name:     ptr.String("__Name__"),
							MinValue: ptr.Float32(1.0),
							MaxValue: ptr.Float32(1.0),
							Step:     ptr.Float32(1.0),
							Value:    ptr.String("__Value__"),
							IsArray:  ptr.Bool(true),
							FileUploaderConfig: &types.FileUploaderFieldConfig{
								AccessLevel: types.StorageAccessLevel("public"),
								AcceptedFileTypes: []string{
									"__Member__",
									"__Member__",
								},
								ShowThumbnails: ptr.Bool(true),
								IsResumable:    ptr.Bool(true),
								MaxFileCount:   ptr.Int32(1),
								MaxSize:        ptr.Int32(1),
							},
						},
						Validations: []types.FieldValidationConfiguration{
							{
								Type: ptr.String("__Type__"),
								StrValues: []string{
									"__Member__",
									"__Member__",
								},
								NumValues: []int32{
									1,
									1,
								},
								ValidationMessage: ptr.String("__ValidationMessage__"),
							},
							{
								Type: ptr.String("__Type__"),
								StrValues: []string{
									"__Member__",
									"__Member__",
								},
								NumValues: []int32{
									1,
									1,
								},
								ValidationMessage: ptr.String("__ValidationMessage__"),
							},
						},
					},
				},
				SectionalElements: map[string]types.SectionalElement{
					"key0": {
						Type: ptr.String("__Type__"),
						Position: &types.FieldPositionMemberFixed{
							Value: types.FixedPosition("first"),
						},
						Text:        ptr.String("__Text__"),
						Level:       ptr.Int32(1),
						Orientation: ptr.String("__Orientation__"),
						Excluded:    ptr.Bool(true),
					},
				},
				SchemaVersion: ptr.String("__SchemaVersion__"),
				Tags: map[string]string{
					"key0": "__Value__",
				},
				Cta: &types.FormCTA{
					Position: types.FormButtonsPosition("top"),
					Clear: &types.FormButton{
						Excluded: ptr.Bool(true),
						Children: ptr.String("__Children__"),
						Position: &types.FieldPositionMemberFixed{
							Value: types.FixedPosition("first"),
						},
					},
					Cancel: &types.FormButton{
						Excluded: ptr.Bool(true),
						Children: ptr.String("__Children__"),
						Position: &types.FieldPositionMemberFixed{
							Value: types.FixedPosition("first"),
						},
					},
					Submit: &types.FormButton{
						Excluded: ptr.Bool(true),
						Children: ptr.String("__Children__"),
						Position: &types.FieldPositionMemberFixed{
							Value: types.FixedPosition("first"),
						},
					},
				},
				LabelDecorator: types.LabelDecorator("required"),
			},
		},
		NextToken: ptr.String("__NextToken__"),
	}
	status, header, body, err := serdeRespReadSnapshot("ExportForms.response")
	if errors.Is(err, fs.ErrNotExist) {
		t.Skip("no response snapshot fixture")
	}
	if err != nil {
		t.Fatal(err)
	}
	svc := serdeRespClient(status, header, body)
	got, err := svc.ExportForms(context.Background(), &ExportFormsInput{})
	if err != nil {
		t.Fatal(err)
	}
	if err := smithytesting.CompareValues(want, got); err != nil {
		t.Errorf("response snapshot mismatch for %s: %v", "ExportForms.response", err)
	}
}

func TestCheckResponseSnapshot_ExportThemes(t *testing.T) {
	want := &ExportThemesOutput{
		Entities: []types.Theme{
			{
				AppId:           ptr.String("__AppId__"),
				EnvironmentName: ptr.String("__EnvironmentName__"),
				Id:              ptr.String("__Id__"),
				Name:            ptr.String("__Name__"),
				CreatedAt:       ptr.Time(time.Date(2000, 1, 1, 0, 0, 0, 0, time.UTC)),
				ModifiedAt:      ptr.Time(time.Date(2000, 1, 1, 0, 0, 0, 0, time.UTC)),
				Values: []types.ThemeValues{
					{
						Key: ptr.String("__Key__"),
						Value: &types.ThemeValue{
							Value: ptr.String("__Value__"),
							Children: []types.ThemeValues{
								{},
								{},
							},
						},
					},
					{
						Key: ptr.String("__Key__"),
						Value: &types.ThemeValue{
							Value: ptr.String("__Value__"),
							Children: []types.ThemeValues{
								{},
								{},
							},
						},
					},
				},
				Overrides: []types.ThemeValues{
					{
						Key: ptr.String("__Key__"),
						Value: &types.ThemeValue{
							Value: ptr.String("__Value__"),
							Children: []types.ThemeValues{
								{},
								{},
							},
						},
					},
					{
						Key: ptr.String("__Key__"),
						Value: &types.ThemeValue{
							Value: ptr.String("__Value__"),
							Children: []types.ThemeValues{
								{},
								{},
							},
						},
					},
				},
				Tags: map[string]string{
					"key0": "__Value__",
				},
			},
			{
				AppId:           ptr.String("__AppId__"),
				EnvironmentName: ptr.String("__EnvironmentName__"),
				Id:              ptr.String("__Id__"),
				Name:            ptr.String("__Name__"),
				CreatedAt:       ptr.Time(time.Date(2000, 1, 1, 0, 0, 0, 0, time.UTC)),
				ModifiedAt:      ptr.Time(time.Date(2000, 1, 1, 0, 0, 0, 0, time.UTC)),
				Values: []types.ThemeValues{
					{
						Key: ptr.String("__Key__"),
						Value: &types.ThemeValue{
							Value: ptr.String("__Value__"),
							Children: []types.ThemeValues{
								{},
								{},
							},
						},
					},
					{
						Key: ptr.String("__Key__"),
						Value: &types.ThemeValue{
							Value: ptr.String("__Value__"),
							Children: []types.ThemeValues{
								{},
								{},
							},
						},
					},
				},
				Overrides: []types.ThemeValues{
					{
						Key: ptr.String("__Key__"),
						Value: &types.ThemeValue{
							Value: ptr.String("__Value__"),
							Children: []types.ThemeValues{
								{},
								{},
							},
						},
					},
					{
						Key: ptr.String("__Key__"),
						Value: &types.ThemeValue{
							Value: ptr.String("__Value__"),
							Children: []types.ThemeValues{
								{},
								{},
							},
						},
					},
				},
				Tags: map[string]string{
					"key0": "__Value__",
				},
			},
		},
		NextToken: ptr.String("__NextToken__"),
	}
	status, header, body, err := serdeRespReadSnapshot("ExportThemes.response")
	if errors.Is(err, fs.ErrNotExist) {
		t.Skip("no response snapshot fixture")
	}
	if err != nil {
		t.Fatal(err)
	}
	svc := serdeRespClient(status, header, body)
	got, err := svc.ExportThemes(context.Background(), &ExportThemesInput{})
	if err != nil {
		t.Fatal(err)
	}
	if err := smithytesting.CompareValues(want, got); err != nil {
		t.Errorf("response snapshot mismatch for %s: %v", "ExportThemes.response", err)
	}
}

func TestCheckResponseSnapshot_GetCodegenJob(t *testing.T) {
	want := &GetCodegenJobOutput{
		Job: &types.CodegenJob{
			Id:              ptr.String("__Id__"),
			AppId:           ptr.String("__AppId__"),
			EnvironmentName: ptr.String("__EnvironmentName__"),
			RenderConfig: &types.CodegenJobRenderConfigMemberReact{
				Value: types.ReactStartCodegenJobData{
					Module:                 types.JSModule("es2020"),
					Target:                 types.JSTarget("es2015"),
					Script:                 types.JSScript("jsx"),
					RenderTypeDeclarations: true,
					InlineSourceMap:        true,
					ApiConfiguration: &types.ApiConfigurationMemberGraphQLConfig{
						Value: types.GraphQLRenderConfig{
							TypesFilePath:         ptr.String("__TypesFilePath__"),
							QueriesFilePath:       ptr.String("__QueriesFilePath__"),
							MutationsFilePath:     ptr.String("__MutationsFilePath__"),
							SubscriptionsFilePath: ptr.String("__SubscriptionsFilePath__"),
							FragmentsFilePath:     ptr.String("__FragmentsFilePath__"),
						},
					},
					Dependencies: map[string]string{
						"key0": "__Value__",
					},
				},
			},
			GenericDataSchema: &types.CodegenJobGenericDataSchema{
				DataSourceType: types.CodegenJobGenericDataSourceType("DataStore"),
				Models: map[string]types.CodegenGenericDataModel{
					"key0": {
						Fields: map[string]types.CodegenGenericDataField{
							"key0": {
								DataType:      types.CodegenGenericDataFieldDataType("ID"),
								DataTypeValue: ptr.String("__DataTypeValue__"),
								Required:      ptr.Bool(true),
								ReadOnly:      ptr.Bool(true),
								IsArray:       ptr.Bool(true),
								Relationship: &types.CodegenGenericDataRelationshipType{
									Type:             types.GenericDataRelationshipType("HAS_MANY"),
									RelatedModelName: ptr.String("__RelatedModelName__"),
									RelatedModelFields: []string{
										"__Member__",
										"__Member__",
									},
									CanUnlinkAssociatedModel:     ptr.Bool(true),
									RelatedJoinFieldName:         ptr.String("__RelatedJoinFieldName__"),
									RelatedJoinTableName:         ptr.String("__RelatedJoinTableName__"),
									BelongsToFieldOnRelatedModel: ptr.String("__BelongsToFieldOnRelatedModel__"),
									AssociatedFields: []string{
										"__Member__",
										"__Member__",
									},
									IsHasManyIndex: ptr.Bool(true),
								},
							},
						},
						IsJoinTable: ptr.Bool(true),
						PrimaryKeys: []string{
							"__Member__",
							"__Member__",
						},
					},
				},
				Enums: map[string]types.CodegenGenericDataEnum{
					"key0": {
						Values: []string{
							"__Member__",
							"__Member__",
						},
					},
				},
				NonModels: map[string]types.CodegenGenericDataNonModel{
					"key0": {
						Fields: map[string]types.CodegenGenericDataField{
							"key0": {
								DataType:      types.CodegenGenericDataFieldDataType("ID"),
								DataTypeValue: ptr.String("__DataTypeValue__"),
								Required:      ptr.Bool(true),
								ReadOnly:      ptr.Bool(true),
								IsArray:       ptr.Bool(true),
								Relationship: &types.CodegenGenericDataRelationshipType{
									Type:             types.GenericDataRelationshipType("HAS_MANY"),
									RelatedModelName: ptr.String("__RelatedModelName__"),
									RelatedModelFields: []string{
										"__Member__",
										"__Member__",
									},
									CanUnlinkAssociatedModel:     ptr.Bool(true),
									RelatedJoinFieldName:         ptr.String("__RelatedJoinFieldName__"),
									RelatedJoinTableName:         ptr.String("__RelatedJoinTableName__"),
									BelongsToFieldOnRelatedModel: ptr.String("__BelongsToFieldOnRelatedModel__"),
									AssociatedFields: []string{
										"__Member__",
										"__Member__",
									},
									IsHasManyIndex: ptr.Bool(true),
								},
							},
						},
					},
				},
			},
			AutoGenerateForms: ptr.Bool(true),
			Features: &types.CodegenFeatureFlags{
				IsRelationshipSupported: ptr.Bool(true),
				IsNonModelSupported:     ptr.Bool(true),
			},
			Status:        types.CodegenJobStatus("in_progress"),
			StatusMessage: ptr.String("__StatusMessage__"),
			Asset: &types.CodegenJobAsset{
				DownloadUrl: ptr.String("__DownloadUrl__"),
			},
			Tags: map[string]string{
				"key0": "__Value__",
			},
			CreatedAt:  ptr.Time(time.Date(2000, 1, 1, 0, 0, 0, 0, time.UTC)),
			ModifiedAt: ptr.Time(time.Date(2000, 1, 1, 0, 0, 0, 0, time.UTC)),
			Dependencies: []types.CodegenDependency{
				{
					Name:             ptr.String("__Name__"),
					SupportedVersion: ptr.String("__SupportedVersion__"),
					IsSemVer:         ptr.Bool(true),
					Reason:           ptr.String("__Reason__"),
				},
				{
					Name:             ptr.String("__Name__"),
					SupportedVersion: ptr.String("__SupportedVersion__"),
					IsSemVer:         ptr.Bool(true),
					Reason:           ptr.String("__Reason__"),
				},
			},
		},
	}
	status, header, body, err := serdeRespReadSnapshot("GetCodegenJob.response")
	if errors.Is(err, fs.ErrNotExist) {
		t.Skip("no response snapshot fixture")
	}
	if err != nil {
		t.Fatal(err)
	}
	svc := serdeRespClient(status, header, body)
	got, err := svc.GetCodegenJob(context.Background(), &GetCodegenJobInput{})
	if err != nil {
		t.Fatal(err)
	}
	if err := smithytesting.CompareValues(want, got); err != nil {
		t.Errorf("response snapshot mismatch for %s: %v", "GetCodegenJob.response", err)
	}
}

func TestCheckResponseSnapshot_GetComponent(t *testing.T) {
	want := &GetComponentOutput{
		Component: &types.Component{
			AppId:           ptr.String("__AppId__"),
			EnvironmentName: ptr.String("__EnvironmentName__"),
			SourceId:        ptr.String("__SourceId__"),
			Id:              ptr.String("__Id__"),
			Name:            ptr.String("__Name__"),
			ComponentType:   ptr.String("__ComponentType__"),
			Properties: map[string]types.ComponentProperty{
				"key0": {
					Value: ptr.String("__Value__"),
					BindingProperties: &types.ComponentPropertyBindingProperties{
						Property: ptr.String("__Property__"),
						Field:    ptr.String("__Field__"),
					},
					CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
						Property: ptr.String("__Property__"),
						Field:    ptr.String("__Field__"),
					},
					DefaultValue: ptr.String("__DefaultValue__"),
					Model:        ptr.String("__Model__"),
					Bindings: map[string]types.FormBindingElement{
						"key0": {
							Element:  ptr.String("__Element__"),
							Property: ptr.String("__Property__"),
						},
					},
					Event:         ptr.String("__Event__"),
					UserAttribute: ptr.String("__UserAttribute__"),
					Concat: []types.ComponentProperty{
						{},
						{},
					},
					Condition: &types.ComponentConditionProperty{
						Property:    ptr.String("__Property__"),
						Field:       ptr.String("__Field__"),
						Operator:    ptr.String("__Operator__"),
						Operand:     ptr.String("__Operand__"),
						Then:        nil,
						Else:        nil,
						OperandType: ptr.String("__OperandType__"),
					},
					Configured:    ptr.Bool(true),
					Type:          ptr.String("__Type__"),
					ImportedValue: ptr.String("__ImportedValue__"),
					ComponentName: ptr.String("__ComponentName__"),
					Property:      ptr.String("__Property__"),
				},
			},
			Children: []types.ComponentChild{
				{
					ComponentType: ptr.String("__ComponentType__"),
					Name:          ptr.String("__Name__"),
					Properties: map[string]types.ComponentProperty{
						"key0": {
							Value: ptr.String("__Value__"),
							BindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							DefaultValue: ptr.String("__DefaultValue__"),
							Model:        ptr.String("__Model__"),
							Bindings: map[string]types.FormBindingElement{
								"key0": {
									Element:  ptr.String("__Element__"),
									Property: ptr.String("__Property__"),
								},
							},
							Event:         ptr.String("__Event__"),
							UserAttribute: ptr.String("__UserAttribute__"),
							Concat: []types.ComponentProperty{
								{},
								{},
							},
							Condition: &types.ComponentConditionProperty{
								Property:    ptr.String("__Property__"),
								Field:       ptr.String("__Field__"),
								Operator:    ptr.String("__Operator__"),
								Operand:     ptr.String("__Operand__"),
								Then:        nil,
								Else:        nil,
								OperandType: ptr.String("__OperandType__"),
							},
							Configured:    ptr.Bool(true),
							Type:          ptr.String("__Type__"),
							ImportedValue: ptr.String("__ImportedValue__"),
							ComponentName: ptr.String("__ComponentName__"),
							Property:      ptr.String("__Property__"),
						},
					},
					Children: []types.ComponentChild{
						{},
						{},
					},
					Events: map[string]types.ComponentEvent{
						"key0": {
							Action: ptr.String("__Action__"),
							Parameters: &types.ActionParameters{
								Type: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Url: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Anchor: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Target: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Global: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Model: ptr.String("__Model__"),
								Id: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Fields: map[string]types.ComponentProperty{
									"key0": {
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
								},
								State: &types.MutationActionSetStateParameter{
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
									Set: &types.ComponentProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
								},
							},
							BindingEvent: ptr.String("__BindingEvent__"),
						},
					},
					SourceId: ptr.String("__SourceId__"),
				},
				{
					ComponentType: ptr.String("__ComponentType__"),
					Name:          ptr.String("__Name__"),
					Properties: map[string]types.ComponentProperty{
						"key0": {
							Value: ptr.String("__Value__"),
							BindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							DefaultValue: ptr.String("__DefaultValue__"),
							Model:        ptr.String("__Model__"),
							Bindings: map[string]types.FormBindingElement{
								"key0": {
									Element:  ptr.String("__Element__"),
									Property: ptr.String("__Property__"),
								},
							},
							Event:         ptr.String("__Event__"),
							UserAttribute: ptr.String("__UserAttribute__"),
							Concat: []types.ComponentProperty{
								{},
								{},
							},
							Condition: &types.ComponentConditionProperty{
								Property:    ptr.String("__Property__"),
								Field:       ptr.String("__Field__"),
								Operator:    ptr.String("__Operator__"),
								Operand:     ptr.String("__Operand__"),
								Then:        nil,
								Else:        nil,
								OperandType: ptr.String("__OperandType__"),
							},
							Configured:    ptr.Bool(true),
							Type:          ptr.String("__Type__"),
							ImportedValue: ptr.String("__ImportedValue__"),
							ComponentName: ptr.String("__ComponentName__"),
							Property:      ptr.String("__Property__"),
						},
					},
					Children: []types.ComponentChild{
						{},
						{},
					},
					Events: map[string]types.ComponentEvent{
						"key0": {
							Action: ptr.String("__Action__"),
							Parameters: &types.ActionParameters{
								Type: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Url: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Anchor: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Target: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Global: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Model: ptr.String("__Model__"),
								Id: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Fields: map[string]types.ComponentProperty{
									"key0": {
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
								},
								State: &types.MutationActionSetStateParameter{
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
									Set: &types.ComponentProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
								},
							},
							BindingEvent: ptr.String("__BindingEvent__"),
						},
					},
					SourceId: ptr.String("__SourceId__"),
				},
			},
			Variants: []types.ComponentVariant{
				{
					VariantValues: map[string]string{
						"key0": "__Value__",
					},
					Overrides: map[string]map[string]string{
						"key0": {
							"key0": "__Value__",
						},
					},
				},
				{
					VariantValues: map[string]string{
						"key0": "__Value__",
					},
					Overrides: map[string]map[string]string{
						"key0": {
							"key0": "__Value__",
						},
					},
				},
			},
			Overrides: map[string]map[string]string{
				"key0": {
					"key0": "__Value__",
				},
			},
			BindingProperties: map[string]types.ComponentBindingPropertiesValue{
				"key0": {
					Type: ptr.String("__Type__"),
					BindingProperties: &types.ComponentBindingPropertiesValueProperties{
						Model: ptr.String("__Model__"),
						Field: ptr.String("__Field__"),
						Predicates: []types.Predicate{
							{
								Or: []types.Predicate{
									{},
									{},
								},
								And: []types.Predicate{
									{},
									{},
								},
								Field:       ptr.String("__Field__"),
								Operator:    ptr.String("__Operator__"),
								Operand:     ptr.String("__Operand__"),
								OperandType: ptr.String("__OperandType__"),
							},
							{
								Or: []types.Predicate{
									{},
									{},
								},
								And: []types.Predicate{
									{},
									{},
								},
								Field:       ptr.String("__Field__"),
								Operator:    ptr.String("__Operator__"),
								Operand:     ptr.String("__Operand__"),
								OperandType: ptr.String("__OperandType__"),
							},
						},
						UserAttribute: ptr.String("__UserAttribute__"),
						Bucket:        ptr.String("__Bucket__"),
						Key:           ptr.String("__Key__"),
						DefaultValue:  ptr.String("__DefaultValue__"),
						SlotName:      ptr.String("__SlotName__"),
					},
					DefaultValue: ptr.String("__DefaultValue__"),
				},
			},
			CollectionProperties: map[string]types.ComponentDataConfiguration{
				"key0": {
					Model: ptr.String("__Model__"),
					Sort: []types.SortProperty{
						{
							Field:     ptr.String("__Field__"),
							Direction: types.SortDirection("ASC"),
						},
						{
							Field:     ptr.String("__Field__"),
							Direction: types.SortDirection("ASC"),
						},
					},
					Predicate: &types.Predicate{
						Or: []types.Predicate{
							{},
							{},
						},
						And: []types.Predicate{
							{},
							{},
						},
						Field:       ptr.String("__Field__"),
						Operator:    ptr.String("__Operator__"),
						Operand:     ptr.String("__Operand__"),
						OperandType: ptr.String("__OperandType__"),
					},
					Identifiers: []string{
						"__Member__",
						"__Member__",
					},
				},
			},
			CreatedAt:  ptr.Time(time.Date(2000, 1, 1, 0, 0, 0, 0, time.UTC)),
			ModifiedAt: ptr.Time(time.Date(2000, 1, 1, 0, 0, 0, 0, time.UTC)),
			Tags: map[string]string{
				"key0": "__Value__",
			},
			Events: map[string]types.ComponentEvent{
				"key0": {
					Action: ptr.String("__Action__"),
					Parameters: &types.ActionParameters{
						Type: &types.ComponentProperty{
							Value: ptr.String("__Value__"),
							BindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							DefaultValue: ptr.String("__DefaultValue__"),
							Model:        ptr.String("__Model__"),
							Bindings: map[string]types.FormBindingElement{
								"key0": {
									Element:  ptr.String("__Element__"),
									Property: ptr.String("__Property__"),
								},
							},
							Event:         ptr.String("__Event__"),
							UserAttribute: ptr.String("__UserAttribute__"),
							Concat: []types.ComponentProperty{
								{},
								{},
							},
							Condition: &types.ComponentConditionProperty{
								Property:    ptr.String("__Property__"),
								Field:       ptr.String("__Field__"),
								Operator:    ptr.String("__Operator__"),
								Operand:     ptr.String("__Operand__"),
								Then:        nil,
								Else:        nil,
								OperandType: ptr.String("__OperandType__"),
							},
							Configured:    ptr.Bool(true),
							Type:          ptr.String("__Type__"),
							ImportedValue: ptr.String("__ImportedValue__"),
							ComponentName: ptr.String("__ComponentName__"),
							Property:      ptr.String("__Property__"),
						},
						Url: &types.ComponentProperty{
							Value: ptr.String("__Value__"),
							BindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							DefaultValue: ptr.String("__DefaultValue__"),
							Model:        ptr.String("__Model__"),
							Bindings: map[string]types.FormBindingElement{
								"key0": {
									Element:  ptr.String("__Element__"),
									Property: ptr.String("__Property__"),
								},
							},
							Event:         ptr.String("__Event__"),
							UserAttribute: ptr.String("__UserAttribute__"),
							Concat: []types.ComponentProperty{
								{},
								{},
							},
							Condition: &types.ComponentConditionProperty{
								Property:    ptr.String("__Property__"),
								Field:       ptr.String("__Field__"),
								Operator:    ptr.String("__Operator__"),
								Operand:     ptr.String("__Operand__"),
								Then:        nil,
								Else:        nil,
								OperandType: ptr.String("__OperandType__"),
							},
							Configured:    ptr.Bool(true),
							Type:          ptr.String("__Type__"),
							ImportedValue: ptr.String("__ImportedValue__"),
							ComponentName: ptr.String("__ComponentName__"),
							Property:      ptr.String("__Property__"),
						},
						Anchor: &types.ComponentProperty{
							Value: ptr.String("__Value__"),
							BindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							DefaultValue: ptr.String("__DefaultValue__"),
							Model:        ptr.String("__Model__"),
							Bindings: map[string]types.FormBindingElement{
								"key0": {
									Element:  ptr.String("__Element__"),
									Property: ptr.String("__Property__"),
								},
							},
							Event:         ptr.String("__Event__"),
							UserAttribute: ptr.String("__UserAttribute__"),
							Concat: []types.ComponentProperty{
								{},
								{},
							},
							Condition: &types.ComponentConditionProperty{
								Property:    ptr.String("__Property__"),
								Field:       ptr.String("__Field__"),
								Operator:    ptr.String("__Operator__"),
								Operand:     ptr.String("__Operand__"),
								Then:        nil,
								Else:        nil,
								OperandType: ptr.String("__OperandType__"),
							},
							Configured:    ptr.Bool(true),
							Type:          ptr.String("__Type__"),
							ImportedValue: ptr.String("__ImportedValue__"),
							ComponentName: ptr.String("__ComponentName__"),
							Property:      ptr.String("__Property__"),
						},
						Target: &types.ComponentProperty{
							Value: ptr.String("__Value__"),
							BindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							DefaultValue: ptr.String("__DefaultValue__"),
							Model:        ptr.String("__Model__"),
							Bindings: map[string]types.FormBindingElement{
								"key0": {
									Element:  ptr.String("__Element__"),
									Property: ptr.String("__Property__"),
								},
							},
							Event:         ptr.String("__Event__"),
							UserAttribute: ptr.String("__UserAttribute__"),
							Concat: []types.ComponentProperty{
								{},
								{},
							},
							Condition: &types.ComponentConditionProperty{
								Property:    ptr.String("__Property__"),
								Field:       ptr.String("__Field__"),
								Operator:    ptr.String("__Operator__"),
								Operand:     ptr.String("__Operand__"),
								Then:        nil,
								Else:        nil,
								OperandType: ptr.String("__OperandType__"),
							},
							Configured:    ptr.Bool(true),
							Type:          ptr.String("__Type__"),
							ImportedValue: ptr.String("__ImportedValue__"),
							ComponentName: ptr.String("__ComponentName__"),
							Property:      ptr.String("__Property__"),
						},
						Global: &types.ComponentProperty{
							Value: ptr.String("__Value__"),
							BindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							DefaultValue: ptr.String("__DefaultValue__"),
							Model:        ptr.String("__Model__"),
							Bindings: map[string]types.FormBindingElement{
								"key0": {
									Element:  ptr.String("__Element__"),
									Property: ptr.String("__Property__"),
								},
							},
							Event:         ptr.String("__Event__"),
							UserAttribute: ptr.String("__UserAttribute__"),
							Concat: []types.ComponentProperty{
								{},
								{},
							},
							Condition: &types.ComponentConditionProperty{
								Property:    ptr.String("__Property__"),
								Field:       ptr.String("__Field__"),
								Operator:    ptr.String("__Operator__"),
								Operand:     ptr.String("__Operand__"),
								Then:        nil,
								Else:        nil,
								OperandType: ptr.String("__OperandType__"),
							},
							Configured:    ptr.Bool(true),
							Type:          ptr.String("__Type__"),
							ImportedValue: ptr.String("__ImportedValue__"),
							ComponentName: ptr.String("__ComponentName__"),
							Property:      ptr.String("__Property__"),
						},
						Model: ptr.String("__Model__"),
						Id: &types.ComponentProperty{
							Value: ptr.String("__Value__"),
							BindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							DefaultValue: ptr.String("__DefaultValue__"),
							Model:        ptr.String("__Model__"),
							Bindings: map[string]types.FormBindingElement{
								"key0": {
									Element:  ptr.String("__Element__"),
									Property: ptr.String("__Property__"),
								},
							},
							Event:         ptr.String("__Event__"),
							UserAttribute: ptr.String("__UserAttribute__"),
							Concat: []types.ComponentProperty{
								{},
								{},
							},
							Condition: &types.ComponentConditionProperty{
								Property:    ptr.String("__Property__"),
								Field:       ptr.String("__Field__"),
								Operator:    ptr.String("__Operator__"),
								Operand:     ptr.String("__Operand__"),
								Then:        nil,
								Else:        nil,
								OperandType: ptr.String("__OperandType__"),
							},
							Configured:    ptr.Bool(true),
							Type:          ptr.String("__Type__"),
							ImportedValue: ptr.String("__ImportedValue__"),
							ComponentName: ptr.String("__ComponentName__"),
							Property:      ptr.String("__Property__"),
						},
						Fields: map[string]types.ComponentProperty{
							"key0": {
								Value: ptr.String("__Value__"),
								BindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								DefaultValue: ptr.String("__DefaultValue__"),
								Model:        ptr.String("__Model__"),
								Bindings: map[string]types.FormBindingElement{
									"key0": {
										Element:  ptr.String("__Element__"),
										Property: ptr.String("__Property__"),
									},
								},
								Event:         ptr.String("__Event__"),
								UserAttribute: ptr.String("__UserAttribute__"),
								Concat: []types.ComponentProperty{
									{},
									{},
								},
								Condition: &types.ComponentConditionProperty{
									Property:    ptr.String("__Property__"),
									Field:       ptr.String("__Field__"),
									Operator:    ptr.String("__Operator__"),
									Operand:     ptr.String("__Operand__"),
									Then:        nil,
									Else:        nil,
									OperandType: ptr.String("__OperandType__"),
								},
								Configured:    ptr.Bool(true),
								Type:          ptr.String("__Type__"),
								ImportedValue: ptr.String("__ImportedValue__"),
								ComponentName: ptr.String("__ComponentName__"),
								Property:      ptr.String("__Property__"),
							},
						},
						State: &types.MutationActionSetStateParameter{
							ComponentName: ptr.String("__ComponentName__"),
							Property:      ptr.String("__Property__"),
							Set: &types.ComponentProperty{
								Value: ptr.String("__Value__"),
								BindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								DefaultValue: ptr.String("__DefaultValue__"),
								Model:        ptr.String("__Model__"),
								Bindings: map[string]types.FormBindingElement{
									"key0": {
										Element:  ptr.String("__Element__"),
										Property: ptr.String("__Property__"),
									},
								},
								Event:         ptr.String("__Event__"),
								UserAttribute: ptr.String("__UserAttribute__"),
								Concat: []types.ComponentProperty{
									{},
									{},
								},
								Condition: &types.ComponentConditionProperty{
									Property:    ptr.String("__Property__"),
									Field:       ptr.String("__Field__"),
									Operator:    ptr.String("__Operator__"),
									Operand:     ptr.String("__Operand__"),
									Then:        nil,
									Else:        nil,
									OperandType: ptr.String("__OperandType__"),
								},
								Configured:    ptr.Bool(true),
								Type:          ptr.String("__Type__"),
								ImportedValue: ptr.String("__ImportedValue__"),
								ComponentName: ptr.String("__ComponentName__"),
								Property:      ptr.String("__Property__"),
							},
						},
					},
					BindingEvent: ptr.String("__BindingEvent__"),
				},
			},
			SchemaVersion: ptr.String("__SchemaVersion__"),
		},
	}
	status, header, body, err := serdeRespReadSnapshot("GetComponent.response")
	if errors.Is(err, fs.ErrNotExist) {
		t.Skip("no response snapshot fixture")
	}
	if err != nil {
		t.Fatal(err)
	}
	svc := serdeRespClient(status, header, body)
	got, err := svc.GetComponent(context.Background(), &GetComponentInput{})
	if err != nil {
		t.Fatal(err)
	}
	if err := smithytesting.CompareValues(want, got); err != nil {
		t.Errorf("response snapshot mismatch for %s: %v", "GetComponent.response", err)
	}
}

func TestCheckResponseSnapshot_GetForm(t *testing.T) {
	want := &GetFormOutput{
		Form: &types.Form{
			AppId:           ptr.String("__AppId__"),
			EnvironmentName: ptr.String("__EnvironmentName__"),
			Id:              ptr.String("__Id__"),
			Name:            ptr.String("__Name__"),
			FormActionType:  types.FormActionType("create"),
			Style: &types.FormStyle{
				HorizontalGap: &types.FormStyleConfigMemberTokenReference{
					Value: "__FormStyleConfigMemberTokenReference__",
				},
				VerticalGap: &types.FormStyleConfigMemberTokenReference{
					Value: "__FormStyleConfigMemberTokenReference__",
				},
				OuterPadding: &types.FormStyleConfigMemberTokenReference{
					Value: "__FormStyleConfigMemberTokenReference__",
				},
			},
			DataType: &types.FormDataTypeConfig{
				DataSourceType: types.FormDataSourceType("DataStore"),
				DataTypeName:   ptr.String("__DataTypeName__"),
			},
			Fields: map[string]types.FieldConfig{
				"key0": {
					Label: ptr.String("__Label__"),
					Position: &types.FieldPositionMemberFixed{
						Value: types.FixedPosition("first"),
					},
					Excluded: ptr.Bool(true),
					InputType: &types.FieldInputConfig{
						Type:               ptr.String("__Type__"),
						Required:           ptr.Bool(true),
						ReadOnly:           ptr.Bool(true),
						Placeholder:        ptr.String("__Placeholder__"),
						DefaultValue:       ptr.String("__DefaultValue__"),
						DescriptiveText:    ptr.String("__DescriptiveText__"),
						DefaultChecked:     ptr.Bool(true),
						DefaultCountryCode: ptr.String("__DefaultCountryCode__"),
						ValueMappings: &types.ValueMappings{
							Values: []types.ValueMapping{
								{
									DisplayValue: &types.FormInputValueProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.FormInputValuePropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										Concat: []types.FormInputValueProperty{
											{},
											{},
										},
									},
									Value: &types.FormInputValueProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.FormInputValuePropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										Concat: []types.FormInputValueProperty{
											{},
											{},
										},
									},
								},
								{
									DisplayValue: &types.FormInputValueProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.FormInputValuePropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										Concat: []types.FormInputValueProperty{
											{},
											{},
										},
									},
									Value: &types.FormInputValueProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.FormInputValuePropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										Concat: []types.FormInputValueProperty{
											{},
											{},
										},
									},
								},
							},
							BindingProperties: map[string]types.FormInputBindingPropertiesValue{
								"key0": {
									Type: ptr.String("__Type__"),
									BindingProperties: &types.FormInputBindingPropertiesValueProperties{
										Model: ptr.String("__Model__"),
									},
								},
							},
						},
						Name:     ptr.String("__Name__"),
						MinValue: ptr.Float32(1.0),
						MaxValue: ptr.Float32(1.0),
						Step:     ptr.Float32(1.0),
						Value:    ptr.String("__Value__"),
						IsArray:  ptr.Bool(true),
						FileUploaderConfig: &types.FileUploaderFieldConfig{
							AccessLevel: types.StorageAccessLevel("public"),
							AcceptedFileTypes: []string{
								"__Member__",
								"__Member__",
							},
							ShowThumbnails: ptr.Bool(true),
							IsResumable:    ptr.Bool(true),
							MaxFileCount:   ptr.Int32(1),
							MaxSize:        ptr.Int32(1),
						},
					},
					Validations: []types.FieldValidationConfiguration{
						{
							Type: ptr.String("__Type__"),
							StrValues: []string{
								"__Member__",
								"__Member__",
							},
							NumValues: []int32{
								1,
								1,
							},
							ValidationMessage: ptr.String("__ValidationMessage__"),
						},
						{
							Type: ptr.String("__Type__"),
							StrValues: []string{
								"__Member__",
								"__Member__",
							},
							NumValues: []int32{
								1,
								1,
							},
							ValidationMessage: ptr.String("__ValidationMessage__"),
						},
					},
				},
			},
			SectionalElements: map[string]types.SectionalElement{
				"key0": {
					Type: ptr.String("__Type__"),
					Position: &types.FieldPositionMemberFixed{
						Value: types.FixedPosition("first"),
					},
					Text:        ptr.String("__Text__"),
					Level:       ptr.Int32(1),
					Orientation: ptr.String("__Orientation__"),
					Excluded:    ptr.Bool(true),
				},
			},
			SchemaVersion: ptr.String("__SchemaVersion__"),
			Tags: map[string]string{
				"key0": "__Value__",
			},
			Cta: &types.FormCTA{
				Position: types.FormButtonsPosition("top"),
				Clear: &types.FormButton{
					Excluded: ptr.Bool(true),
					Children: ptr.String("__Children__"),
					Position: &types.FieldPositionMemberFixed{
						Value: types.FixedPosition("first"),
					},
				},
				Cancel: &types.FormButton{
					Excluded: ptr.Bool(true),
					Children: ptr.String("__Children__"),
					Position: &types.FieldPositionMemberFixed{
						Value: types.FixedPosition("first"),
					},
				},
				Submit: &types.FormButton{
					Excluded: ptr.Bool(true),
					Children: ptr.String("__Children__"),
					Position: &types.FieldPositionMemberFixed{
						Value: types.FixedPosition("first"),
					},
				},
			},
			LabelDecorator: types.LabelDecorator("required"),
		},
	}
	status, header, body, err := serdeRespReadSnapshot("GetForm.response")
	if errors.Is(err, fs.ErrNotExist) {
		t.Skip("no response snapshot fixture")
	}
	if err != nil {
		t.Fatal(err)
	}
	svc := serdeRespClient(status, header, body)
	got, err := svc.GetForm(context.Background(), &GetFormInput{})
	if err != nil {
		t.Fatal(err)
	}
	if err := smithytesting.CompareValues(want, got); err != nil {
		t.Errorf("response snapshot mismatch for %s: %v", "GetForm.response", err)
	}
}

func TestCheckResponseSnapshot_GetMetadata(t *testing.T) {
	want := &GetMetadataOutput{
		Features: map[string]string{
			"key0": "__Value__",
		},
	}
	status, header, body, err := serdeRespReadSnapshot("GetMetadata.response")
	if errors.Is(err, fs.ErrNotExist) {
		t.Skip("no response snapshot fixture")
	}
	if err != nil {
		t.Fatal(err)
	}
	svc := serdeRespClient(status, header, body)
	got, err := svc.GetMetadata(context.Background(), &GetMetadataInput{})
	if err != nil {
		t.Fatal(err)
	}
	if err := smithytesting.CompareValues(want, got); err != nil {
		t.Errorf("response snapshot mismatch for %s: %v", "GetMetadata.response", err)
	}
}

func TestCheckResponseSnapshot_GetTheme(t *testing.T) {
	want := &GetThemeOutput{
		Theme: &types.Theme{
			AppId:           ptr.String("__AppId__"),
			EnvironmentName: ptr.String("__EnvironmentName__"),
			Id:              ptr.String("__Id__"),
			Name:            ptr.String("__Name__"),
			CreatedAt:       ptr.Time(time.Date(2000, 1, 1, 0, 0, 0, 0, time.UTC)),
			ModifiedAt:      ptr.Time(time.Date(2000, 1, 1, 0, 0, 0, 0, time.UTC)),
			Values: []types.ThemeValues{
				{
					Key: ptr.String("__Key__"),
					Value: &types.ThemeValue{
						Value: ptr.String("__Value__"),
						Children: []types.ThemeValues{
							{},
							{},
						},
					},
				},
				{
					Key: ptr.String("__Key__"),
					Value: &types.ThemeValue{
						Value: ptr.String("__Value__"),
						Children: []types.ThemeValues{
							{},
							{},
						},
					},
				},
			},
			Overrides: []types.ThemeValues{
				{
					Key: ptr.String("__Key__"),
					Value: &types.ThemeValue{
						Value: ptr.String("__Value__"),
						Children: []types.ThemeValues{
							{},
							{},
						},
					},
				},
				{
					Key: ptr.String("__Key__"),
					Value: &types.ThemeValue{
						Value: ptr.String("__Value__"),
						Children: []types.ThemeValues{
							{},
							{},
						},
					},
				},
			},
			Tags: map[string]string{
				"key0": "__Value__",
			},
		},
	}
	status, header, body, err := serdeRespReadSnapshot("GetTheme.response")
	if errors.Is(err, fs.ErrNotExist) {
		t.Skip("no response snapshot fixture")
	}
	if err != nil {
		t.Fatal(err)
	}
	svc := serdeRespClient(status, header, body)
	got, err := svc.GetTheme(context.Background(), &GetThemeInput{})
	if err != nil {
		t.Fatal(err)
	}
	if err := smithytesting.CompareValues(want, got); err != nil {
		t.Errorf("response snapshot mismatch for %s: %v", "GetTheme.response", err)
	}
}

func TestCheckResponseSnapshot_ListCodegenJobs(t *testing.T) {
	want := &ListCodegenJobsOutput{
		Entities: []types.CodegenJobSummary{
			{
				AppId:           ptr.String("__AppId__"),
				EnvironmentName: ptr.String("__EnvironmentName__"),
				Id:              ptr.String("__Id__"),
				CreatedAt:       ptr.Time(time.Date(2000, 1, 1, 0, 0, 0, 0, time.UTC)),
				ModifiedAt:      ptr.Time(time.Date(2000, 1, 1, 0, 0, 0, 0, time.UTC)),
			},
			{
				AppId:           ptr.String("__AppId__"),
				EnvironmentName: ptr.String("__EnvironmentName__"),
				Id:              ptr.String("__Id__"),
				CreatedAt:       ptr.Time(time.Date(2000, 1, 1, 0, 0, 0, 0, time.UTC)),
				ModifiedAt:      ptr.Time(time.Date(2000, 1, 1, 0, 0, 0, 0, time.UTC)),
			},
		},
		NextToken: ptr.String("__NextToken__"),
	}
	status, header, body, err := serdeRespReadSnapshot("ListCodegenJobs.response")
	if errors.Is(err, fs.ErrNotExist) {
		t.Skip("no response snapshot fixture")
	}
	if err != nil {
		t.Fatal(err)
	}
	svc := serdeRespClient(status, header, body)
	got, err := svc.ListCodegenJobs(context.Background(), &ListCodegenJobsInput{})
	if err != nil {
		t.Fatal(err)
	}
	if err := smithytesting.CompareValues(want, got); err != nil {
		t.Errorf("response snapshot mismatch for %s: %v", "ListCodegenJobs.response", err)
	}
}

func TestCheckResponseSnapshot_ListComponents(t *testing.T) {
	want := &ListComponentsOutput{
		Entities: []types.ComponentSummary{
			{
				AppId:           ptr.String("__AppId__"),
				EnvironmentName: ptr.String("__EnvironmentName__"),
				Id:              ptr.String("__Id__"),
				Name:            ptr.String("__Name__"),
				ComponentType:   ptr.String("__ComponentType__"),
			},
			{
				AppId:           ptr.String("__AppId__"),
				EnvironmentName: ptr.String("__EnvironmentName__"),
				Id:              ptr.String("__Id__"),
				Name:            ptr.String("__Name__"),
				ComponentType:   ptr.String("__ComponentType__"),
			},
		},
		NextToken: ptr.String("__NextToken__"),
	}
	status, header, body, err := serdeRespReadSnapshot("ListComponents.response")
	if errors.Is(err, fs.ErrNotExist) {
		t.Skip("no response snapshot fixture")
	}
	if err != nil {
		t.Fatal(err)
	}
	svc := serdeRespClient(status, header, body)
	got, err := svc.ListComponents(context.Background(), &ListComponentsInput{})
	if err != nil {
		t.Fatal(err)
	}
	if err := smithytesting.CompareValues(want, got); err != nil {
		t.Errorf("response snapshot mismatch for %s: %v", "ListComponents.response", err)
	}
}

func TestCheckResponseSnapshot_ListForms(t *testing.T) {
	want := &ListFormsOutput{
		Entities: []types.FormSummary{
			{
				AppId: ptr.String("__AppId__"),
				DataType: &types.FormDataTypeConfig{
					DataSourceType: types.FormDataSourceType("DataStore"),
					DataTypeName:   ptr.String("__DataTypeName__"),
				},
				EnvironmentName: ptr.String("__EnvironmentName__"),
				FormActionType:  types.FormActionType("create"),
				Id:              ptr.String("__Id__"),
				Name:            ptr.String("__Name__"),
			},
			{
				AppId: ptr.String("__AppId__"),
				DataType: &types.FormDataTypeConfig{
					DataSourceType: types.FormDataSourceType("DataStore"),
					DataTypeName:   ptr.String("__DataTypeName__"),
				},
				EnvironmentName: ptr.String("__EnvironmentName__"),
				FormActionType:  types.FormActionType("create"),
				Id:              ptr.String("__Id__"),
				Name:            ptr.String("__Name__"),
			},
		},
		NextToken: ptr.String("__NextToken__"),
	}
	status, header, body, err := serdeRespReadSnapshot("ListForms.response")
	if errors.Is(err, fs.ErrNotExist) {
		t.Skip("no response snapshot fixture")
	}
	if err != nil {
		t.Fatal(err)
	}
	svc := serdeRespClient(status, header, body)
	got, err := svc.ListForms(context.Background(), &ListFormsInput{})
	if err != nil {
		t.Fatal(err)
	}
	if err := smithytesting.CompareValues(want, got); err != nil {
		t.Errorf("response snapshot mismatch for %s: %v", "ListForms.response", err)
	}
}

func TestCheckResponseSnapshot_ListTagsForResource(t *testing.T) {
	want := &ListTagsForResourceOutput{
		Tags: map[string]string{
			"key0": "__Value__",
		},
	}
	status, header, body, err := serdeRespReadSnapshot("ListTagsForResource.response")
	if errors.Is(err, fs.ErrNotExist) {
		t.Skip("no response snapshot fixture")
	}
	if err != nil {
		t.Fatal(err)
	}
	svc := serdeRespClient(status, header, body)
	got, err := svc.ListTagsForResource(context.Background(), &ListTagsForResourceInput{})
	if err != nil {
		t.Fatal(err)
	}
	if err := smithytesting.CompareValues(want, got); err != nil {
		t.Errorf("response snapshot mismatch for %s: %v", "ListTagsForResource.response", err)
	}
}

func TestCheckResponseSnapshot_ListThemes(t *testing.T) {
	want := &ListThemesOutput{
		Entities: []types.ThemeSummary{
			{
				AppId:           ptr.String("__AppId__"),
				EnvironmentName: ptr.String("__EnvironmentName__"),
				Id:              ptr.String("__Id__"),
				Name:            ptr.String("__Name__"),
			},
			{
				AppId:           ptr.String("__AppId__"),
				EnvironmentName: ptr.String("__EnvironmentName__"),
				Id:              ptr.String("__Id__"),
				Name:            ptr.String("__Name__"),
			},
		},
		NextToken: ptr.String("__NextToken__"),
	}
	status, header, body, err := serdeRespReadSnapshot("ListThemes.response")
	if errors.Is(err, fs.ErrNotExist) {
		t.Skip("no response snapshot fixture")
	}
	if err != nil {
		t.Fatal(err)
	}
	svc := serdeRespClient(status, header, body)
	got, err := svc.ListThemes(context.Background(), &ListThemesInput{})
	if err != nil {
		t.Fatal(err)
	}
	if err := smithytesting.CompareValues(want, got); err != nil {
		t.Errorf("response snapshot mismatch for %s: %v", "ListThemes.response", err)
	}
}

func TestCheckResponseSnapshot_PutMetadataFlag(t *testing.T) {
	want := &PutMetadataFlagOutput{}
	status, header, body, err := serdeRespReadSnapshot("PutMetadataFlag.response")
	if errors.Is(err, fs.ErrNotExist) {
		t.Skip("no response snapshot fixture")
	}
	if err != nil {
		t.Fatal(err)
	}
	svc := serdeRespClient(status, header, body)
	got, err := svc.PutMetadataFlag(context.Background(), &PutMetadataFlagInput{})
	if err != nil {
		t.Fatal(err)
	}
	if err := smithytesting.CompareValues(want, got); err != nil {
		t.Errorf("response snapshot mismatch for %s: %v", "PutMetadataFlag.response", err)
	}
}

func TestCheckResponseSnapshot_RefreshToken(t *testing.T) {
	want := &RefreshTokenOutput{
		AccessToken: ptr.String("__AccessToken__"),
		ExpiresIn:   ptr.Int32(1),
	}
	status, header, body, err := serdeRespReadSnapshot("RefreshToken.response")
	if errors.Is(err, fs.ErrNotExist) {
		t.Skip("no response snapshot fixture")
	}
	if err != nil {
		t.Fatal(err)
	}
	svc := serdeRespClient(status, header, body)
	got, err := svc.RefreshToken(context.Background(), &RefreshTokenInput{})
	if err != nil {
		t.Fatal(err)
	}
	if err := smithytesting.CompareValues(want, got); err != nil {
		t.Errorf("response snapshot mismatch for %s: %v", "RefreshToken.response", err)
	}
}

func TestCheckResponseSnapshot_StartCodegenJob(t *testing.T) {
	want := &StartCodegenJobOutput{
		Entity: &types.CodegenJob{
			Id:              ptr.String("__Id__"),
			AppId:           ptr.String("__AppId__"),
			EnvironmentName: ptr.String("__EnvironmentName__"),
			RenderConfig: &types.CodegenJobRenderConfigMemberReact{
				Value: types.ReactStartCodegenJobData{
					Module:                 types.JSModule("es2020"),
					Target:                 types.JSTarget("es2015"),
					Script:                 types.JSScript("jsx"),
					RenderTypeDeclarations: true,
					InlineSourceMap:        true,
					ApiConfiguration: &types.ApiConfigurationMemberGraphQLConfig{
						Value: types.GraphQLRenderConfig{
							TypesFilePath:         ptr.String("__TypesFilePath__"),
							QueriesFilePath:       ptr.String("__QueriesFilePath__"),
							MutationsFilePath:     ptr.String("__MutationsFilePath__"),
							SubscriptionsFilePath: ptr.String("__SubscriptionsFilePath__"),
							FragmentsFilePath:     ptr.String("__FragmentsFilePath__"),
						},
					},
					Dependencies: map[string]string{
						"key0": "__Value__",
					},
				},
			},
			GenericDataSchema: &types.CodegenJobGenericDataSchema{
				DataSourceType: types.CodegenJobGenericDataSourceType("DataStore"),
				Models: map[string]types.CodegenGenericDataModel{
					"key0": {
						Fields: map[string]types.CodegenGenericDataField{
							"key0": {
								DataType:      types.CodegenGenericDataFieldDataType("ID"),
								DataTypeValue: ptr.String("__DataTypeValue__"),
								Required:      ptr.Bool(true),
								ReadOnly:      ptr.Bool(true),
								IsArray:       ptr.Bool(true),
								Relationship: &types.CodegenGenericDataRelationshipType{
									Type:             types.GenericDataRelationshipType("HAS_MANY"),
									RelatedModelName: ptr.String("__RelatedModelName__"),
									RelatedModelFields: []string{
										"__Member__",
										"__Member__",
									},
									CanUnlinkAssociatedModel:     ptr.Bool(true),
									RelatedJoinFieldName:         ptr.String("__RelatedJoinFieldName__"),
									RelatedJoinTableName:         ptr.String("__RelatedJoinTableName__"),
									BelongsToFieldOnRelatedModel: ptr.String("__BelongsToFieldOnRelatedModel__"),
									AssociatedFields: []string{
										"__Member__",
										"__Member__",
									},
									IsHasManyIndex: ptr.Bool(true),
								},
							},
						},
						IsJoinTable: ptr.Bool(true),
						PrimaryKeys: []string{
							"__Member__",
							"__Member__",
						},
					},
				},
				Enums: map[string]types.CodegenGenericDataEnum{
					"key0": {
						Values: []string{
							"__Member__",
							"__Member__",
						},
					},
				},
				NonModels: map[string]types.CodegenGenericDataNonModel{
					"key0": {
						Fields: map[string]types.CodegenGenericDataField{
							"key0": {
								DataType:      types.CodegenGenericDataFieldDataType("ID"),
								DataTypeValue: ptr.String("__DataTypeValue__"),
								Required:      ptr.Bool(true),
								ReadOnly:      ptr.Bool(true),
								IsArray:       ptr.Bool(true),
								Relationship: &types.CodegenGenericDataRelationshipType{
									Type:             types.GenericDataRelationshipType("HAS_MANY"),
									RelatedModelName: ptr.String("__RelatedModelName__"),
									RelatedModelFields: []string{
										"__Member__",
										"__Member__",
									},
									CanUnlinkAssociatedModel:     ptr.Bool(true),
									RelatedJoinFieldName:         ptr.String("__RelatedJoinFieldName__"),
									RelatedJoinTableName:         ptr.String("__RelatedJoinTableName__"),
									BelongsToFieldOnRelatedModel: ptr.String("__BelongsToFieldOnRelatedModel__"),
									AssociatedFields: []string{
										"__Member__",
										"__Member__",
									},
									IsHasManyIndex: ptr.Bool(true),
								},
							},
						},
					},
				},
			},
			AutoGenerateForms: ptr.Bool(true),
			Features: &types.CodegenFeatureFlags{
				IsRelationshipSupported: ptr.Bool(true),
				IsNonModelSupported:     ptr.Bool(true),
			},
			Status:        types.CodegenJobStatus("in_progress"),
			StatusMessage: ptr.String("__StatusMessage__"),
			Asset: &types.CodegenJobAsset{
				DownloadUrl: ptr.String("__DownloadUrl__"),
			},
			Tags: map[string]string{
				"key0": "__Value__",
			},
			CreatedAt:  ptr.Time(time.Date(2000, 1, 1, 0, 0, 0, 0, time.UTC)),
			ModifiedAt: ptr.Time(time.Date(2000, 1, 1, 0, 0, 0, 0, time.UTC)),
			Dependencies: []types.CodegenDependency{
				{
					Name:             ptr.String("__Name__"),
					SupportedVersion: ptr.String("__SupportedVersion__"),
					IsSemVer:         ptr.Bool(true),
					Reason:           ptr.String("__Reason__"),
				},
				{
					Name:             ptr.String("__Name__"),
					SupportedVersion: ptr.String("__SupportedVersion__"),
					IsSemVer:         ptr.Bool(true),
					Reason:           ptr.String("__Reason__"),
				},
			},
		},
	}
	status, header, body, err := serdeRespReadSnapshot("StartCodegenJob.response")
	if errors.Is(err, fs.ErrNotExist) {
		t.Skip("no response snapshot fixture")
	}
	if err != nil {
		t.Fatal(err)
	}
	svc := serdeRespClient(status, header, body)
	got, err := svc.StartCodegenJob(context.Background(), &StartCodegenJobInput{})
	if err != nil {
		t.Fatal(err)
	}
	if err := smithytesting.CompareValues(want, got); err != nil {
		t.Errorf("response snapshot mismatch for %s: %v", "StartCodegenJob.response", err)
	}
}

func TestCheckResponseSnapshot_TagResource(t *testing.T) {
	want := &TagResourceOutput{}
	status, header, body, err := serdeRespReadSnapshot("TagResource.response")
	if errors.Is(err, fs.ErrNotExist) {
		t.Skip("no response snapshot fixture")
	}
	if err != nil {
		t.Fatal(err)
	}
	svc := serdeRespClient(status, header, body)
	got, err := svc.TagResource(context.Background(), &TagResourceInput{})
	if err != nil {
		t.Fatal(err)
	}
	if err := smithytesting.CompareValues(want, got); err != nil {
		t.Errorf("response snapshot mismatch for %s: %v", "TagResource.response", err)
	}
}

func TestCheckResponseSnapshot_UntagResource(t *testing.T) {
	want := &UntagResourceOutput{}
	status, header, body, err := serdeRespReadSnapshot("UntagResource.response")
	if errors.Is(err, fs.ErrNotExist) {
		t.Skip("no response snapshot fixture")
	}
	if err != nil {
		t.Fatal(err)
	}
	svc := serdeRespClient(status, header, body)
	got, err := svc.UntagResource(context.Background(), &UntagResourceInput{})
	if err != nil {
		t.Fatal(err)
	}
	if err := smithytesting.CompareValues(want, got); err != nil {
		t.Errorf("response snapshot mismatch for %s: %v", "UntagResource.response", err)
	}
}

func TestCheckResponseSnapshot_UpdateComponent(t *testing.T) {
	want := &UpdateComponentOutput{
		Entity: &types.Component{
			AppId:           ptr.String("__AppId__"),
			EnvironmentName: ptr.String("__EnvironmentName__"),
			SourceId:        ptr.String("__SourceId__"),
			Id:              ptr.String("__Id__"),
			Name:            ptr.String("__Name__"),
			ComponentType:   ptr.String("__ComponentType__"),
			Properties: map[string]types.ComponentProperty{
				"key0": {
					Value: ptr.String("__Value__"),
					BindingProperties: &types.ComponentPropertyBindingProperties{
						Property: ptr.String("__Property__"),
						Field:    ptr.String("__Field__"),
					},
					CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
						Property: ptr.String("__Property__"),
						Field:    ptr.String("__Field__"),
					},
					DefaultValue: ptr.String("__DefaultValue__"),
					Model:        ptr.String("__Model__"),
					Bindings: map[string]types.FormBindingElement{
						"key0": {
							Element:  ptr.String("__Element__"),
							Property: ptr.String("__Property__"),
						},
					},
					Event:         ptr.String("__Event__"),
					UserAttribute: ptr.String("__UserAttribute__"),
					Concat: []types.ComponentProperty{
						{},
						{},
					},
					Condition: &types.ComponentConditionProperty{
						Property:    ptr.String("__Property__"),
						Field:       ptr.String("__Field__"),
						Operator:    ptr.String("__Operator__"),
						Operand:     ptr.String("__Operand__"),
						Then:        nil,
						Else:        nil,
						OperandType: ptr.String("__OperandType__"),
					},
					Configured:    ptr.Bool(true),
					Type:          ptr.String("__Type__"),
					ImportedValue: ptr.String("__ImportedValue__"),
					ComponentName: ptr.String("__ComponentName__"),
					Property:      ptr.String("__Property__"),
				},
			},
			Children: []types.ComponentChild{
				{
					ComponentType: ptr.String("__ComponentType__"),
					Name:          ptr.String("__Name__"),
					Properties: map[string]types.ComponentProperty{
						"key0": {
							Value: ptr.String("__Value__"),
							BindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							DefaultValue: ptr.String("__DefaultValue__"),
							Model:        ptr.String("__Model__"),
							Bindings: map[string]types.FormBindingElement{
								"key0": {
									Element:  ptr.String("__Element__"),
									Property: ptr.String("__Property__"),
								},
							},
							Event:         ptr.String("__Event__"),
							UserAttribute: ptr.String("__UserAttribute__"),
							Concat: []types.ComponentProperty{
								{},
								{},
							},
							Condition: &types.ComponentConditionProperty{
								Property:    ptr.String("__Property__"),
								Field:       ptr.String("__Field__"),
								Operator:    ptr.String("__Operator__"),
								Operand:     ptr.String("__Operand__"),
								Then:        nil,
								Else:        nil,
								OperandType: ptr.String("__OperandType__"),
							},
							Configured:    ptr.Bool(true),
							Type:          ptr.String("__Type__"),
							ImportedValue: ptr.String("__ImportedValue__"),
							ComponentName: ptr.String("__ComponentName__"),
							Property:      ptr.String("__Property__"),
						},
					},
					Children: []types.ComponentChild{
						{},
						{},
					},
					Events: map[string]types.ComponentEvent{
						"key0": {
							Action: ptr.String("__Action__"),
							Parameters: &types.ActionParameters{
								Type: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Url: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Anchor: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Target: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Global: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Model: ptr.String("__Model__"),
								Id: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Fields: map[string]types.ComponentProperty{
									"key0": {
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
								},
								State: &types.MutationActionSetStateParameter{
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
									Set: &types.ComponentProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
								},
							},
							BindingEvent: ptr.String("__BindingEvent__"),
						},
					},
					SourceId: ptr.String("__SourceId__"),
				},
				{
					ComponentType: ptr.String("__ComponentType__"),
					Name:          ptr.String("__Name__"),
					Properties: map[string]types.ComponentProperty{
						"key0": {
							Value: ptr.String("__Value__"),
							BindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							DefaultValue: ptr.String("__DefaultValue__"),
							Model:        ptr.String("__Model__"),
							Bindings: map[string]types.FormBindingElement{
								"key0": {
									Element:  ptr.String("__Element__"),
									Property: ptr.String("__Property__"),
								},
							},
							Event:         ptr.String("__Event__"),
							UserAttribute: ptr.String("__UserAttribute__"),
							Concat: []types.ComponentProperty{
								{},
								{},
							},
							Condition: &types.ComponentConditionProperty{
								Property:    ptr.String("__Property__"),
								Field:       ptr.String("__Field__"),
								Operator:    ptr.String("__Operator__"),
								Operand:     ptr.String("__Operand__"),
								Then:        nil,
								Else:        nil,
								OperandType: ptr.String("__OperandType__"),
							},
							Configured:    ptr.Bool(true),
							Type:          ptr.String("__Type__"),
							ImportedValue: ptr.String("__ImportedValue__"),
							ComponentName: ptr.String("__ComponentName__"),
							Property:      ptr.String("__Property__"),
						},
					},
					Children: []types.ComponentChild{
						{},
						{},
					},
					Events: map[string]types.ComponentEvent{
						"key0": {
							Action: ptr.String("__Action__"),
							Parameters: &types.ActionParameters{
								Type: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Url: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Anchor: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Target: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Global: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Model: ptr.String("__Model__"),
								Id: &types.ComponentProperty{
									Value: ptr.String("__Value__"),
									BindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
										Property: ptr.String("__Property__"),
										Field:    ptr.String("__Field__"),
									},
									DefaultValue: ptr.String("__DefaultValue__"),
									Model:        ptr.String("__Model__"),
									Bindings: map[string]types.FormBindingElement{
										"key0": {
											Element:  ptr.String("__Element__"),
											Property: ptr.String("__Property__"),
										},
									},
									Event:         ptr.String("__Event__"),
									UserAttribute: ptr.String("__UserAttribute__"),
									Concat: []types.ComponentProperty{
										{},
										{},
									},
									Condition: &types.ComponentConditionProperty{
										Property:    ptr.String("__Property__"),
										Field:       ptr.String("__Field__"),
										Operator:    ptr.String("__Operator__"),
										Operand:     ptr.String("__Operand__"),
										Then:        nil,
										Else:        nil,
										OperandType: ptr.String("__OperandType__"),
									},
									Configured:    ptr.Bool(true),
									Type:          ptr.String("__Type__"),
									ImportedValue: ptr.String("__ImportedValue__"),
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
								},
								Fields: map[string]types.ComponentProperty{
									"key0": {
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
								},
								State: &types.MutationActionSetStateParameter{
									ComponentName: ptr.String("__ComponentName__"),
									Property:      ptr.String("__Property__"),
									Set: &types.ComponentProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										DefaultValue: ptr.String("__DefaultValue__"),
										Model:        ptr.String("__Model__"),
										Bindings: map[string]types.FormBindingElement{
											"key0": {
												Element:  ptr.String("__Element__"),
												Property: ptr.String("__Property__"),
											},
										},
										Event:         ptr.String("__Event__"),
										UserAttribute: ptr.String("__UserAttribute__"),
										Concat: []types.ComponentProperty{
											{},
											{},
										},
										Condition: &types.ComponentConditionProperty{
											Property:    ptr.String("__Property__"),
											Field:       ptr.String("__Field__"),
											Operator:    ptr.String("__Operator__"),
											Operand:     ptr.String("__Operand__"),
											Then:        nil,
											Else:        nil,
											OperandType: ptr.String("__OperandType__"),
										},
										Configured:    ptr.Bool(true),
										Type:          ptr.String("__Type__"),
										ImportedValue: ptr.String("__ImportedValue__"),
										ComponentName: ptr.String("__ComponentName__"),
										Property:      ptr.String("__Property__"),
									},
								},
							},
							BindingEvent: ptr.String("__BindingEvent__"),
						},
					},
					SourceId: ptr.String("__SourceId__"),
				},
			},
			Variants: []types.ComponentVariant{
				{
					VariantValues: map[string]string{
						"key0": "__Value__",
					},
					Overrides: map[string]map[string]string{
						"key0": {
							"key0": "__Value__",
						},
					},
				},
				{
					VariantValues: map[string]string{
						"key0": "__Value__",
					},
					Overrides: map[string]map[string]string{
						"key0": {
							"key0": "__Value__",
						},
					},
				},
			},
			Overrides: map[string]map[string]string{
				"key0": {
					"key0": "__Value__",
				},
			},
			BindingProperties: map[string]types.ComponentBindingPropertiesValue{
				"key0": {
					Type: ptr.String("__Type__"),
					BindingProperties: &types.ComponentBindingPropertiesValueProperties{
						Model: ptr.String("__Model__"),
						Field: ptr.String("__Field__"),
						Predicates: []types.Predicate{
							{
								Or: []types.Predicate{
									{},
									{},
								},
								And: []types.Predicate{
									{},
									{},
								},
								Field:       ptr.String("__Field__"),
								Operator:    ptr.String("__Operator__"),
								Operand:     ptr.String("__Operand__"),
								OperandType: ptr.String("__OperandType__"),
							},
							{
								Or: []types.Predicate{
									{},
									{},
								},
								And: []types.Predicate{
									{},
									{},
								},
								Field:       ptr.String("__Field__"),
								Operator:    ptr.String("__Operator__"),
								Operand:     ptr.String("__Operand__"),
								OperandType: ptr.String("__OperandType__"),
							},
						},
						UserAttribute: ptr.String("__UserAttribute__"),
						Bucket:        ptr.String("__Bucket__"),
						Key:           ptr.String("__Key__"),
						DefaultValue:  ptr.String("__DefaultValue__"),
						SlotName:      ptr.String("__SlotName__"),
					},
					DefaultValue: ptr.String("__DefaultValue__"),
				},
			},
			CollectionProperties: map[string]types.ComponentDataConfiguration{
				"key0": {
					Model: ptr.String("__Model__"),
					Sort: []types.SortProperty{
						{
							Field:     ptr.String("__Field__"),
							Direction: types.SortDirection("ASC"),
						},
						{
							Field:     ptr.String("__Field__"),
							Direction: types.SortDirection("ASC"),
						},
					},
					Predicate: &types.Predicate{
						Or: []types.Predicate{
							{},
							{},
						},
						And: []types.Predicate{
							{},
							{},
						},
						Field:       ptr.String("__Field__"),
						Operator:    ptr.String("__Operator__"),
						Operand:     ptr.String("__Operand__"),
						OperandType: ptr.String("__OperandType__"),
					},
					Identifiers: []string{
						"__Member__",
						"__Member__",
					},
				},
			},
			CreatedAt:  ptr.Time(time.Date(2000, 1, 1, 0, 0, 0, 0, time.UTC)),
			ModifiedAt: ptr.Time(time.Date(2000, 1, 1, 0, 0, 0, 0, time.UTC)),
			Tags: map[string]string{
				"key0": "__Value__",
			},
			Events: map[string]types.ComponentEvent{
				"key0": {
					Action: ptr.String("__Action__"),
					Parameters: &types.ActionParameters{
						Type: &types.ComponentProperty{
							Value: ptr.String("__Value__"),
							BindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							DefaultValue: ptr.String("__DefaultValue__"),
							Model:        ptr.String("__Model__"),
							Bindings: map[string]types.FormBindingElement{
								"key0": {
									Element:  ptr.String("__Element__"),
									Property: ptr.String("__Property__"),
								},
							},
							Event:         ptr.String("__Event__"),
							UserAttribute: ptr.String("__UserAttribute__"),
							Concat: []types.ComponentProperty{
								{},
								{},
							},
							Condition: &types.ComponentConditionProperty{
								Property:    ptr.String("__Property__"),
								Field:       ptr.String("__Field__"),
								Operator:    ptr.String("__Operator__"),
								Operand:     ptr.String("__Operand__"),
								Then:        nil,
								Else:        nil,
								OperandType: ptr.String("__OperandType__"),
							},
							Configured:    ptr.Bool(true),
							Type:          ptr.String("__Type__"),
							ImportedValue: ptr.String("__ImportedValue__"),
							ComponentName: ptr.String("__ComponentName__"),
							Property:      ptr.String("__Property__"),
						},
						Url: &types.ComponentProperty{
							Value: ptr.String("__Value__"),
							BindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							DefaultValue: ptr.String("__DefaultValue__"),
							Model:        ptr.String("__Model__"),
							Bindings: map[string]types.FormBindingElement{
								"key0": {
									Element:  ptr.String("__Element__"),
									Property: ptr.String("__Property__"),
								},
							},
							Event:         ptr.String("__Event__"),
							UserAttribute: ptr.String("__UserAttribute__"),
							Concat: []types.ComponentProperty{
								{},
								{},
							},
							Condition: &types.ComponentConditionProperty{
								Property:    ptr.String("__Property__"),
								Field:       ptr.String("__Field__"),
								Operator:    ptr.String("__Operator__"),
								Operand:     ptr.String("__Operand__"),
								Then:        nil,
								Else:        nil,
								OperandType: ptr.String("__OperandType__"),
							},
							Configured:    ptr.Bool(true),
							Type:          ptr.String("__Type__"),
							ImportedValue: ptr.String("__ImportedValue__"),
							ComponentName: ptr.String("__ComponentName__"),
							Property:      ptr.String("__Property__"),
						},
						Anchor: &types.ComponentProperty{
							Value: ptr.String("__Value__"),
							BindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							DefaultValue: ptr.String("__DefaultValue__"),
							Model:        ptr.String("__Model__"),
							Bindings: map[string]types.FormBindingElement{
								"key0": {
									Element:  ptr.String("__Element__"),
									Property: ptr.String("__Property__"),
								},
							},
							Event:         ptr.String("__Event__"),
							UserAttribute: ptr.String("__UserAttribute__"),
							Concat: []types.ComponentProperty{
								{},
								{},
							},
							Condition: &types.ComponentConditionProperty{
								Property:    ptr.String("__Property__"),
								Field:       ptr.String("__Field__"),
								Operator:    ptr.String("__Operator__"),
								Operand:     ptr.String("__Operand__"),
								Then:        nil,
								Else:        nil,
								OperandType: ptr.String("__OperandType__"),
							},
							Configured:    ptr.Bool(true),
							Type:          ptr.String("__Type__"),
							ImportedValue: ptr.String("__ImportedValue__"),
							ComponentName: ptr.String("__ComponentName__"),
							Property:      ptr.String("__Property__"),
						},
						Target: &types.ComponentProperty{
							Value: ptr.String("__Value__"),
							BindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							DefaultValue: ptr.String("__DefaultValue__"),
							Model:        ptr.String("__Model__"),
							Bindings: map[string]types.FormBindingElement{
								"key0": {
									Element:  ptr.String("__Element__"),
									Property: ptr.String("__Property__"),
								},
							},
							Event:         ptr.String("__Event__"),
							UserAttribute: ptr.String("__UserAttribute__"),
							Concat: []types.ComponentProperty{
								{},
								{},
							},
							Condition: &types.ComponentConditionProperty{
								Property:    ptr.String("__Property__"),
								Field:       ptr.String("__Field__"),
								Operator:    ptr.String("__Operator__"),
								Operand:     ptr.String("__Operand__"),
								Then:        nil,
								Else:        nil,
								OperandType: ptr.String("__OperandType__"),
							},
							Configured:    ptr.Bool(true),
							Type:          ptr.String("__Type__"),
							ImportedValue: ptr.String("__ImportedValue__"),
							ComponentName: ptr.String("__ComponentName__"),
							Property:      ptr.String("__Property__"),
						},
						Global: &types.ComponentProperty{
							Value: ptr.String("__Value__"),
							BindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							DefaultValue: ptr.String("__DefaultValue__"),
							Model:        ptr.String("__Model__"),
							Bindings: map[string]types.FormBindingElement{
								"key0": {
									Element:  ptr.String("__Element__"),
									Property: ptr.String("__Property__"),
								},
							},
							Event:         ptr.String("__Event__"),
							UserAttribute: ptr.String("__UserAttribute__"),
							Concat: []types.ComponentProperty{
								{},
								{},
							},
							Condition: &types.ComponentConditionProperty{
								Property:    ptr.String("__Property__"),
								Field:       ptr.String("__Field__"),
								Operator:    ptr.String("__Operator__"),
								Operand:     ptr.String("__Operand__"),
								Then:        nil,
								Else:        nil,
								OperandType: ptr.String("__OperandType__"),
							},
							Configured:    ptr.Bool(true),
							Type:          ptr.String("__Type__"),
							ImportedValue: ptr.String("__ImportedValue__"),
							ComponentName: ptr.String("__ComponentName__"),
							Property:      ptr.String("__Property__"),
						},
						Model: ptr.String("__Model__"),
						Id: &types.ComponentProperty{
							Value: ptr.String("__Value__"),
							BindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
								Property: ptr.String("__Property__"),
								Field:    ptr.String("__Field__"),
							},
							DefaultValue: ptr.String("__DefaultValue__"),
							Model:        ptr.String("__Model__"),
							Bindings: map[string]types.FormBindingElement{
								"key0": {
									Element:  ptr.String("__Element__"),
									Property: ptr.String("__Property__"),
								},
							},
							Event:         ptr.String("__Event__"),
							UserAttribute: ptr.String("__UserAttribute__"),
							Concat: []types.ComponentProperty{
								{},
								{},
							},
							Condition: &types.ComponentConditionProperty{
								Property:    ptr.String("__Property__"),
								Field:       ptr.String("__Field__"),
								Operator:    ptr.String("__Operator__"),
								Operand:     ptr.String("__Operand__"),
								Then:        nil,
								Else:        nil,
								OperandType: ptr.String("__OperandType__"),
							},
							Configured:    ptr.Bool(true),
							Type:          ptr.String("__Type__"),
							ImportedValue: ptr.String("__ImportedValue__"),
							ComponentName: ptr.String("__ComponentName__"),
							Property:      ptr.String("__Property__"),
						},
						Fields: map[string]types.ComponentProperty{
							"key0": {
								Value: ptr.String("__Value__"),
								BindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								DefaultValue: ptr.String("__DefaultValue__"),
								Model:        ptr.String("__Model__"),
								Bindings: map[string]types.FormBindingElement{
									"key0": {
										Element:  ptr.String("__Element__"),
										Property: ptr.String("__Property__"),
									},
								},
								Event:         ptr.String("__Event__"),
								UserAttribute: ptr.String("__UserAttribute__"),
								Concat: []types.ComponentProperty{
									{},
									{},
								},
								Condition: &types.ComponentConditionProperty{
									Property:    ptr.String("__Property__"),
									Field:       ptr.String("__Field__"),
									Operator:    ptr.String("__Operator__"),
									Operand:     ptr.String("__Operand__"),
									Then:        nil,
									Else:        nil,
									OperandType: ptr.String("__OperandType__"),
								},
								Configured:    ptr.Bool(true),
								Type:          ptr.String("__Type__"),
								ImportedValue: ptr.String("__ImportedValue__"),
								ComponentName: ptr.String("__ComponentName__"),
								Property:      ptr.String("__Property__"),
							},
						},
						State: &types.MutationActionSetStateParameter{
							ComponentName: ptr.String("__ComponentName__"),
							Property:      ptr.String("__Property__"),
							Set: &types.ComponentProperty{
								Value: ptr.String("__Value__"),
								BindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								CollectionBindingProperties: &types.ComponentPropertyBindingProperties{
									Property: ptr.String("__Property__"),
									Field:    ptr.String("__Field__"),
								},
								DefaultValue: ptr.String("__DefaultValue__"),
								Model:        ptr.String("__Model__"),
								Bindings: map[string]types.FormBindingElement{
									"key0": {
										Element:  ptr.String("__Element__"),
										Property: ptr.String("__Property__"),
									},
								},
								Event:         ptr.String("__Event__"),
								UserAttribute: ptr.String("__UserAttribute__"),
								Concat: []types.ComponentProperty{
									{},
									{},
								},
								Condition: &types.ComponentConditionProperty{
									Property:    ptr.String("__Property__"),
									Field:       ptr.String("__Field__"),
									Operator:    ptr.String("__Operator__"),
									Operand:     ptr.String("__Operand__"),
									Then:        nil,
									Else:        nil,
									OperandType: ptr.String("__OperandType__"),
								},
								Configured:    ptr.Bool(true),
								Type:          ptr.String("__Type__"),
								ImportedValue: ptr.String("__ImportedValue__"),
								ComponentName: ptr.String("__ComponentName__"),
								Property:      ptr.String("__Property__"),
							},
						},
					},
					BindingEvent: ptr.String("__BindingEvent__"),
				},
			},
			SchemaVersion: ptr.String("__SchemaVersion__"),
		},
	}
	status, header, body, err := serdeRespReadSnapshot("UpdateComponent.response")
	if errors.Is(err, fs.ErrNotExist) {
		t.Skip("no response snapshot fixture")
	}
	if err != nil {
		t.Fatal(err)
	}
	svc := serdeRespClient(status, header, body)
	got, err := svc.UpdateComponent(context.Background(), &UpdateComponentInput{})
	if err != nil {
		t.Fatal(err)
	}
	if err := smithytesting.CompareValues(want, got); err != nil {
		t.Errorf("response snapshot mismatch for %s: %v", "UpdateComponent.response", err)
	}
}

func TestCheckResponseSnapshot_UpdateForm(t *testing.T) {
	want := &UpdateFormOutput{
		Entity: &types.Form{
			AppId:           ptr.String("__AppId__"),
			EnvironmentName: ptr.String("__EnvironmentName__"),
			Id:              ptr.String("__Id__"),
			Name:            ptr.String("__Name__"),
			FormActionType:  types.FormActionType("create"),
			Style: &types.FormStyle{
				HorizontalGap: &types.FormStyleConfigMemberTokenReference{
					Value: "__FormStyleConfigMemberTokenReference__",
				},
				VerticalGap: &types.FormStyleConfigMemberTokenReference{
					Value: "__FormStyleConfigMemberTokenReference__",
				},
				OuterPadding: &types.FormStyleConfigMemberTokenReference{
					Value: "__FormStyleConfigMemberTokenReference__",
				},
			},
			DataType: &types.FormDataTypeConfig{
				DataSourceType: types.FormDataSourceType("DataStore"),
				DataTypeName:   ptr.String("__DataTypeName__"),
			},
			Fields: map[string]types.FieldConfig{
				"key0": {
					Label: ptr.String("__Label__"),
					Position: &types.FieldPositionMemberFixed{
						Value: types.FixedPosition("first"),
					},
					Excluded: ptr.Bool(true),
					InputType: &types.FieldInputConfig{
						Type:               ptr.String("__Type__"),
						Required:           ptr.Bool(true),
						ReadOnly:           ptr.Bool(true),
						Placeholder:        ptr.String("__Placeholder__"),
						DefaultValue:       ptr.String("__DefaultValue__"),
						DescriptiveText:    ptr.String("__DescriptiveText__"),
						DefaultChecked:     ptr.Bool(true),
						DefaultCountryCode: ptr.String("__DefaultCountryCode__"),
						ValueMappings: &types.ValueMappings{
							Values: []types.ValueMapping{
								{
									DisplayValue: &types.FormInputValueProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.FormInputValuePropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										Concat: []types.FormInputValueProperty{
											{},
											{},
										},
									},
									Value: &types.FormInputValueProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.FormInputValuePropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										Concat: []types.FormInputValueProperty{
											{},
											{},
										},
									},
								},
								{
									DisplayValue: &types.FormInputValueProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.FormInputValuePropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										Concat: []types.FormInputValueProperty{
											{},
											{},
										},
									},
									Value: &types.FormInputValueProperty{
										Value: ptr.String("__Value__"),
										BindingProperties: &types.FormInputValuePropertyBindingProperties{
											Property: ptr.String("__Property__"),
											Field:    ptr.String("__Field__"),
										},
										Concat: []types.FormInputValueProperty{
											{},
											{},
										},
									},
								},
							},
							BindingProperties: map[string]types.FormInputBindingPropertiesValue{
								"key0": {
									Type: ptr.String("__Type__"),
									BindingProperties: &types.FormInputBindingPropertiesValueProperties{
										Model: ptr.String("__Model__"),
									},
								},
							},
						},
						Name:     ptr.String("__Name__"),
						MinValue: ptr.Float32(1.0),
						MaxValue: ptr.Float32(1.0),
						Step:     ptr.Float32(1.0),
						Value:    ptr.String("__Value__"),
						IsArray:  ptr.Bool(true),
						FileUploaderConfig: &types.FileUploaderFieldConfig{
							AccessLevel: types.StorageAccessLevel("public"),
							AcceptedFileTypes: []string{
								"__Member__",
								"__Member__",
							},
							ShowThumbnails: ptr.Bool(true),
							IsResumable:    ptr.Bool(true),
							MaxFileCount:   ptr.Int32(1),
							MaxSize:        ptr.Int32(1),
						},
					},
					Validations: []types.FieldValidationConfiguration{
						{
							Type: ptr.String("__Type__"),
							StrValues: []string{
								"__Member__",
								"__Member__",
							},
							NumValues: []int32{
								1,
								1,
							},
							ValidationMessage: ptr.String("__ValidationMessage__"),
						},
						{
							Type: ptr.String("__Type__"),
							StrValues: []string{
								"__Member__",
								"__Member__",
							},
							NumValues: []int32{
								1,
								1,
							},
							ValidationMessage: ptr.String("__ValidationMessage__"),
						},
					},
				},
			},
			SectionalElements: map[string]types.SectionalElement{
				"key0": {
					Type: ptr.String("__Type__"),
					Position: &types.FieldPositionMemberFixed{
						Value: types.FixedPosition("first"),
					},
					Text:        ptr.String("__Text__"),
					Level:       ptr.Int32(1),
					Orientation: ptr.String("__Orientation__"),
					Excluded:    ptr.Bool(true),
				},
			},
			SchemaVersion: ptr.String("__SchemaVersion__"),
			Tags: map[string]string{
				"key0": "__Value__",
			},
			Cta: &types.FormCTA{
				Position: types.FormButtonsPosition("top"),
				Clear: &types.FormButton{
					Excluded: ptr.Bool(true),
					Children: ptr.String("__Children__"),
					Position: &types.FieldPositionMemberFixed{
						Value: types.FixedPosition("first"),
					},
				},
				Cancel: &types.FormButton{
					Excluded: ptr.Bool(true),
					Children: ptr.String("__Children__"),
					Position: &types.FieldPositionMemberFixed{
						Value: types.FixedPosition("first"),
					},
				},
				Submit: &types.FormButton{
					Excluded: ptr.Bool(true),
					Children: ptr.String("__Children__"),
					Position: &types.FieldPositionMemberFixed{
						Value: types.FixedPosition("first"),
					},
				},
			},
			LabelDecorator: types.LabelDecorator("required"),
		},
	}
	status, header, body, err := serdeRespReadSnapshot("UpdateForm.response")
	if errors.Is(err, fs.ErrNotExist) {
		t.Skip("no response snapshot fixture")
	}
	if err != nil {
		t.Fatal(err)
	}
	svc := serdeRespClient(status, header, body)
	got, err := svc.UpdateForm(context.Background(), &UpdateFormInput{})
	if err != nil {
		t.Fatal(err)
	}
	if err := smithytesting.CompareValues(want, got); err != nil {
		t.Errorf("response snapshot mismatch for %s: %v", "UpdateForm.response", err)
	}
}

func TestCheckResponseSnapshot_UpdateTheme(t *testing.T) {
	want := &UpdateThemeOutput{
		Entity: &types.Theme{
			AppId:           ptr.String("__AppId__"),
			EnvironmentName: ptr.String("__EnvironmentName__"),
			Id:              ptr.String("__Id__"),
			Name:            ptr.String("__Name__"),
			CreatedAt:       ptr.Time(time.Date(2000, 1, 1, 0, 0, 0, 0, time.UTC)),
			ModifiedAt:      ptr.Time(time.Date(2000, 1, 1, 0, 0, 0, 0, time.UTC)),
			Values: []types.ThemeValues{
				{
					Key: ptr.String("__Key__"),
					Value: &types.ThemeValue{
						Value: ptr.String("__Value__"),
						Children: []types.ThemeValues{
							{},
							{},
						},
					},
				},
				{
					Key: ptr.String("__Key__"),
					Value: &types.ThemeValue{
						Value: ptr.String("__Value__"),
						Children: []types.ThemeValues{
							{},
							{},
						},
					},
				},
			},
			Overrides: []types.ThemeValues{
				{
					Key: ptr.String("__Key__"),
					Value: &types.ThemeValue{
						Value: ptr.String("__Value__"),
						Children: []types.ThemeValues{
							{},
							{},
						},
					},
				},
				{
					Key: ptr.String("__Key__"),
					Value: &types.ThemeValue{
						Value: ptr.String("__Value__"),
						Children: []types.ThemeValues{
							{},
							{},
						},
					},
				},
			},
			Tags: map[string]string{
				"key0": "__Value__",
			},
		},
	}
	status, header, body, err := serdeRespReadSnapshot("UpdateTheme.response")
	if errors.Is(err, fs.ErrNotExist) {
		t.Skip("no response snapshot fixture")
	}
	if err != nil {
		t.Fatal(err)
	}
	svc := serdeRespClient(status, header, body)
	got, err := svc.UpdateTheme(context.Background(), &UpdateThemeInput{})
	if err != nil {
		t.Fatal(err)
	}
	if err := smithytesting.CompareValues(want, got); err != nil {
		t.Errorf("response snapshot mismatch for %s: %v", "UpdateTheme.response", err)
	}
}

func TestCheckResponseSnapshot_Error_InternalServerException(t *testing.T) {
	want := &types.InternalServerException{
		Message: ptr.String("__Message__"),
	}
	status, header, body, err := serdeRespReadSnapshot("InternalServerException.error")
	if errors.Is(err, fs.ErrNotExist) {
		t.Skip("no response snapshot fixture")
	}
	if err != nil {
		t.Fatal(err)
	}
	svc := serdeRespClient(status, header, body)
	_, opErr := svc.CreateComponent(context.Background(), &CreateComponentInput{})
	if opErr == nil {
		t.Fatal("expected error, got nil")
	}
	var got *types.InternalServerException
	if !errors.As(opErr, &got) {
		t.Fatalf("expected types.InternalServerException, got %v", opErr)
	}
	if err := smithytesting.CompareValues(want, got); err != nil {
		t.Errorf("error response snapshot mismatch for %s: %v", "InternalServerException.error", err)
	}
}

func TestCheckResponseSnapshot_Error_InvalidParameterException(t *testing.T) {
	want := &types.InvalidParameterException{
		Message: ptr.String("__Message__"),
	}
	status, header, body, err := serdeRespReadSnapshot("InvalidParameterException.error")
	if errors.Is(err, fs.ErrNotExist) {
		t.Skip("no response snapshot fixture")
	}
	if err != nil {
		t.Fatal(err)
	}
	svc := serdeRespClient(status, header, body)
	_, opErr := svc.CreateComponent(context.Background(), &CreateComponentInput{})
	if opErr == nil {
		t.Fatal("expected error, got nil")
	}
	var got *types.InvalidParameterException
	if !errors.As(opErr, &got) {
		t.Fatalf("expected types.InvalidParameterException, got %v", opErr)
	}
	if err := smithytesting.CompareValues(want, got); err != nil {
		t.Errorf("error response snapshot mismatch for %s: %v", "InvalidParameterException.error", err)
	}
}

func TestCheckResponseSnapshot_Error_ResourceConflictException(t *testing.T) {
	want := &types.ResourceConflictException{
		Message: ptr.String("__Message__"),
	}
	status, header, body, err := serdeRespReadSnapshot("ResourceConflictException.error")
	if errors.Is(err, fs.ErrNotExist) {
		t.Skip("no response snapshot fixture")
	}
	if err != nil {
		t.Fatal(err)
	}
	svc := serdeRespClient(status, header, body)
	_, opErr := svc.CreateComponent(context.Background(), &CreateComponentInput{})
	if opErr == nil {
		t.Fatal("expected error, got nil")
	}
	var got *types.ResourceConflictException
	if !errors.As(opErr, &got) {
		t.Fatalf("expected types.ResourceConflictException, got %v", opErr)
	}
	if err := smithytesting.CompareValues(want, got); err != nil {
		t.Errorf("error response snapshot mismatch for %s: %v", "ResourceConflictException.error", err)
	}
}

func TestCheckResponseSnapshot_Error_ResourceNotFoundException(t *testing.T) {
	want := &types.ResourceNotFoundException{
		Message: ptr.String("__Message__"),
	}
	status, header, body, err := serdeRespReadSnapshot("ResourceNotFoundException.error")
	if errors.Is(err, fs.ErrNotExist) {
		t.Skip("no response snapshot fixture")
	}
	if err != nil {
		t.Fatal(err)
	}
	svc := serdeRespClient(status, header, body)
	_, opErr := svc.DeleteComponent(context.Background(), &DeleteComponentInput{})
	if opErr == nil {
		t.Fatal("expected error, got nil")
	}
	var got *types.ResourceNotFoundException
	if !errors.As(opErr, &got) {
		t.Fatalf("expected types.ResourceNotFoundException, got %v", opErr)
	}
	if err := smithytesting.CompareValues(want, got); err != nil {
		t.Errorf("error response snapshot mismatch for %s: %v", "ResourceNotFoundException.error", err)
	}
}

func TestCheckResponseSnapshot_Error_ServiceQuotaExceededException(t *testing.T) {
	want := &types.ServiceQuotaExceededException{
		Message: ptr.String("__Message__"),
	}
	status, header, body, err := serdeRespReadSnapshot("ServiceQuotaExceededException.error")
	if errors.Is(err, fs.ErrNotExist) {
		t.Skip("no response snapshot fixture")
	}
	if err != nil {
		t.Fatal(err)
	}
	svc := serdeRespClient(status, header, body)
	_, opErr := svc.CreateComponent(context.Background(), &CreateComponentInput{})
	if opErr == nil {
		t.Fatal("expected error, got nil")
	}
	var got *types.ServiceQuotaExceededException
	if !errors.As(opErr, &got) {
		t.Fatalf("expected types.ServiceQuotaExceededException, got %v", opErr)
	}
	if err := smithytesting.CompareValues(want, got); err != nil {
		t.Errorf("error response snapshot mismatch for %s: %v", "ServiceQuotaExceededException.error", err)
	}
}

func TestCheckResponseSnapshot_Error_ThrottlingException(t *testing.T) {
	want := &types.ThrottlingException{
		Message: ptr.String("__Message__"),
	}
	status, header, body, err := serdeRespReadSnapshot("ThrottlingException.error")
	if errors.Is(err, fs.ErrNotExist) {
		t.Skip("no response snapshot fixture")
	}
	if err != nil {
		t.Fatal(err)
	}
	svc := serdeRespClient(status, header, body)
	_, opErr := svc.GetCodegenJob(context.Background(), &GetCodegenJobInput{})
	if opErr == nil {
		t.Fatal("expected error, got nil")
	}
	var got *types.ThrottlingException
	if !errors.As(opErr, &got) {
		t.Fatalf("expected types.ThrottlingException, got %v", opErr)
	}
	if err := smithytesting.CompareValues(want, got); err != nil {
		t.Errorf("error response snapshot mismatch for %s: %v", "ThrottlingException.error", err)
	}
}

func TestCheckResponseSnapshot_Error_UnauthorizedException(t *testing.T) {
	want := &types.UnauthorizedException{
		Message: ptr.String("__Message__"),
	}
	status, header, body, err := serdeRespReadSnapshot("UnauthorizedException.error")
	if errors.Is(err, fs.ErrNotExist) {
		t.Skip("no response snapshot fixture")
	}
	if err != nil {
		t.Fatal(err)
	}
	svc := serdeRespClient(status, header, body)
	_, opErr := svc.GetMetadata(context.Background(), &GetMetadataInput{})
	if opErr == nil {
		t.Fatal("expected error, got nil")
	}
	var got *types.UnauthorizedException
	if !errors.As(opErr, &got) {
		t.Fatalf("expected types.UnauthorizedException, got %v", opErr)
	}
	if err := smithytesting.CompareValues(want, got); err != nil {
		t.Errorf("error response snapshot mismatch for %s: %v", "UnauthorizedException.error", err)
	}
}
